@@ -24,28 +24,37 @@
  *                                                                           *
  *****************************************************************************/
 #include "awarddxmarathon.h"
+//#include <QDebug>
 
-DXMarathon::DXMarathon()
+DXMarathon::DXMarathon(DataProxy *dp)
 {
-    dataProxy = new DataProxy_SQLite();
+    //qDebug() << "DXMarathon::DXMarathon"  << endl;
+    dataProxy = dp;
+    //qDebug() << "DXMarathon::DXMarathon - END"  << endl;
 }
 
 
+int DXMarathon::getDXMarathonQSO(const int _year, const int _logNumber)
+{
+      //qDebug() << "DXMarathon::getDXMarathonQSO: " << QString::number(_year) << endl;
+    return dataProxy->getQSOonYear(_year, _logNumber);
+}
+
 int DXMarathon::getDXMarathonDXCC(const int _year, const int _logNumber)
 {
-    //qDebug() << "DXMarathon::getDXMarathonDXCC: " << QString::number(_year) << endl;
+      //qDebug() << "DXMarathon::getDXMarathonDXCC: " << QString::number(_year) << endl;
     return dataProxy->getDXCConYear(_year, _logNumber);
 }
 
 int DXMarathon::getDXMarathonCQ(const int _year, const int _logNumber)
 {
-    //qDebug() << "DXMarathon::getDXMarathonCQ: " << QString::number(_year) << endl;
+      //qDebug() << "DXMarathon::getDXMarathonCQ: " << QString::number(_year) << endl;
     return dataProxy->getCQzonYear(_year, _logNumber);
 }
 
 int DXMarathon::getDXMarathonScore(const int _year, const int _logNumber)
 {
-    //qDebug() << "DXMarathon::getDXMarathonScore: " << QString::number(_year) << endl;
+      //qDebug() << "DXMarathon::getDXMarathonScore: " << QString::number(_year) << endl;
 
     return ( getDXMarathonDXCC(_year, _logNumber) + getDXMarathonCQ(_year, _logNumber));
 
