@@ -36,22 +36,23 @@
 #include <QStringList>
 #include <QProgressDialog>
 #include <QMultiHash>
+#include <QObject>
+#include <QtGlobal>
 
 #include "world.h"
 #include "awarddxmarathon.h"
 #include "dataproxy.h"
-#include "dataproxy_sqlite.h"
 #include "utilities.h"
 
 class QProgressDialog;
 
-class Awards
-{
-     //Q_OBJECT
+
+class Awards : public QObject {
+     Q_OBJECT
     //friend class World;
 
 public:
-    Awards();
+    Awards(DataProxy *dp);
     ~Awards();
     void setAwards(const int _qsoId);
     void setAwards(const int _dxcc, const int _waz, const int _band, const int _mode, const int _workedOrConfirmed, const int _logNumber, const int _qsoId);
@@ -59,9 +60,10 @@ public:
     _workedOrConfirmed = 0     Set as Worked
     _workedOrConfirmed = 1     Set as Confirmed
     */
-
+    void setManageModes(const bool _manageModes=false);   // Defines if the mode is to be taken into account when calculating an award
 
     void recalculateAwards();
+    //void recalculateDXCC(const int _logNumber);
     //void setAwards(const int _qsoId, bool modify);
     int getDXCCWorked(const int _logNumber);
     int getDXCCConfirmed(const int _logNumber);
@@ -77,14 +79,16 @@ public:
 
     QString checkIfValidIOTA(const QString _tiota); //TODO: There is an equivalent function in the MainWindowInputOthers class. I should use only one!
 
+    int getEntityDXStatus (const int _enti, const int _bandid, int _modeid = -1, int _log = -1);
     int getDXStatus (const QStringList _qs);
     QString getDXStatusString (const int _status); // Needs to be called with the output of getDXStatus
     QString getDXCCStatusBand(const int _dxcc, const int _band, const int _logNumber=0); // Returns -, W or C (Not worked, worked, Confirmed)
 
     void setColors (const QString _newOne, const QString _needed, const QString _worked, const QString _confirmed, const QString _default);
-    QColor getQRZDXStatusColor(const QStringList _qs);
+    QColor getQRZDXStatusColor(const QStringList _qs); // Receives Entity, band, mode & log
     QColor getDefaultColor();
 
+    int getDXMarathonQSO(const int _year, const int _logNumber);
     int getDXMarathonDXCC(const int _year, const int _logNumber);
     int getDXMarathonCQ(const int _year, const int _logNumber);
     int getDXMarathonScore(const int _year, const int _logNumber);
@@ -106,7 +110,7 @@ public:
 private:
 
     void setAwardDXCC(const int _qsoId);
-    bool setAwardDXCC(const int _dxcc, const int _band, const int _mode, const int _workedOrConfirmed, const int _logNumber, const int _qsoId);
+    //bool setAwardDXCC(const int _dxcc, const int _band, const int _mode, const QString _workedOrConfirmed, const int _logNumber, const int _qsoId);
     int setAwardDXCCst(const int _dxcc, const int _band, const int _mode, const bool _confirmed, const int _logNumber, const int _qsoId);
 
     int setAwardDXCCConfirmed(const int _band, const int _mode, const int _dxcc, const int _newQSOid); // Changes the status of a DXCC from worked to confirmed
@@ -128,7 +132,7 @@ private:
     /**/
 
     void setAwardWAZ(const int _qsoId);
-    bool setAwardWAZ(const int _cqz, const int _band, const int _mode, const int _workedOrConfirmed, const int _logNumber, const int _qsoId);
+    //bool setAwardWAZ(const int _cqz, const int _band, const int _mode, const QString _workedOrConfirmed, const int _logNumber, const int _qsoId);
     int setAwardWAZst(const int _cqz, const int _band, const int _mode, const bool _confirmed, const int _logNumber, const int _qsoId);
     /*
     _confirmed = 0     Set as Worked
@@ -151,7 +155,11 @@ private:
     typedef QMultiHash<int, int> DXStatus;
 
     DXStatus dxccWorked, dxccConfirmed, wazWorked, wazConfirmed;
+    bool manageModes;
 
+signals:
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void awardDXCCUpdated();
 
 };
 #endif // AWARDS_H
