@@ -39,45 +39,77 @@
 
 class QSqlRelationalTableModel;
 
-// Last db update 0.0.6
-// Previous db update 0.0.7
-const float DBVersionf = 0.009;
+// Previous db update 0.011
+const float DBVersionf = 0.012; // TODO:
+
+struct AwarddxccEntry
+{ // Information to update the awarddxcc table; For other Award tables, the DXCC is just the ID of the award element
+    QString dxcc;
+    QString band;
+    QString mode;
+    QString status;
+    QString logNumber;
+    QString qsoID;
+};
+
+struct AwarddxccEntryCheck
+{ // Information to update the awarddxcc table; For other Award tables, the DXCC is just the ID of the award element
+    QString dxcc;
+    QString band;
+    QString mode;
+    QString status;
+    QString logNumber;
+};
 
 class DataBase
 {
 
 public:
-    DataBase();
+    DataBase(const QString _parentClass, const QString _DBName);
     //DataBase(const QString _softVersion, bool  inmemoryonly = false);
-    DataBase(const QString _softVersion);
+    DataBase(const QString _parentClass, const QString _softVersion, const QString _DBName);
     ~DataBase();
-    bool createConnection();
+    QString getSoftVersion();
+    QString getDBVersion();
+    QString getDBName();
+
+    bool createConnection(bool newDB=false);    // If true that means that we are creating the DB,
+                                                // not just connecting to an existing one.
+                                                // That will be done in the default path
+    bool reConnect(const QString _DBName);
+    //bool setDir(const QString _dir);
+    QStringList getColumnNamesFromTable(const QString _tableName);
 
-    //bool beginTransaction();
 
     bool isValidBand (const QString b);
-    bool isValidMode (const QString b, const bool _tmp);
+    bool isValidMode (const QString b, const bool _tmp=false);
     bool isValidBandNumber (const int b);
     bool isValidModeNumber (const int b);
     QString getBandNameFromNumber(const int _n);
-    QString getModeNameFromNumber(const int _n, const bool _tmp);
-    QString getSubModeNameFromNumber(const int _n, const bool _tmp);
+    QString getModeNameFromNumber(const int _n, bool _tmp=false);
+    QString getSubModeNameFromNumber(const int _n, bool _tmp=false);
 
     int getBandIdFromName(const QString b);
     int getModeIdFromName(const QString b);
-    int getModeIdFromSubMode(const QString b, const bool _tmp);
+    int getModeIdFromSubMode(const QString b);
 
     bool createBandModeMaps();
     int getBandIDFromName2(const QString b);
     int getModeIDFromName2(const QString b);
+    int getSubModeIDFromName2(const QString b);
+
     QString getBandNameFromID2(const int _i);
     QString getModeNameFromID2(const int _i);
+    QString getSubModeNameFromID2(const int _i);
 
     int getBandIdFromFreq(const QString fr); //Freq should be in MHz
     bool isThisFreqInBand(const QString b, const QString fr); //Freq should be in MHz
 
     QString getFreqFromBandId(const int _i);
 
+    int getLogTypeNumber(const QString _logType);
+    QString getLogTypeName(const int _logType);
+
     bool unMarkAllQSO();
     bool updateIfNeeded();
     void compress();
@@ -85,7 +117,22 @@ public:
     bool updateTheEntityTableISONames();
     bool updateTableLogs();
 
+    bool queryAddField(const QString _field, const QString value);
+    //bool queryPrepare();
+    //bool queryExec();
+
+    bool queryPrepare(const QString _query);
+    bool queryBind(const QString _field, const QString value);
+    bool updateAwardDXCCTable();
+    bool updateAwardWAZTable();
+    int getNumberOfQsos(const int _logNumber);
+
+
 private:
+    bool beginTransaction();
+    bool commitTransaction();
+    bool execQuery(const QString function, const QString stringQuery);
+
     bool createDataBase();
     bool isTheDBCreated();
     bool hasTheTableData(const QString _tableName);
@@ -97,19 +144,22 @@ private:
     bool updateTo007();
     bool updateTo008();
     bool updateTo009(); // Updates DB and add the Satellite tables
+    bool updateTo010(); // Updates DB and recreates the supportedcontest table
+    bool updateTo011(); // Updates DB and recreates Satellite data
     bool updateTableLog(const int _v);
+    bool updateDBVersion();
 
     bool createTheBandQuickReference();
     bool createTheModeQuickReference();
 
     //bool updateLog(); // Updates the log table
+    bool recreateTableLog();
     bool createTableLog(bool temp = false); // false creates the production DB. True a temporal one.
     bool createTableLogs(const bool real=true); // real = true creates the production DB. False a temporal one.
 
     bool createTableEntity(const bool NoTmp);
     bool updateTableEntity();
 
-    bool createTablePropModes();
     bool createTableClubLogStatus();
     bool populateTableClubLogStatus();
 
@@ -119,17 +169,33 @@ private:
 
     bool createTableBand(const bool NoTmp);
     bool populateTableBand(const bool NoTmp);
+    bool recreateTableBand();
 
+    bool recreateTableDXCC();
+    bool createTableAwardDXCC();
+    bool recreateTableWAZ();
+    bool createTableAwardWAZ();
+
+    bool recreateSatelliteData();
     bool createTableSatellites(const bool NoTmp);
     bool populateTableSatellites(const bool NoTmp);
 
-    bool recreateContestData();
-    bool createTableContest();
-    bool populateContestData();
+    bool recreatePropModes();
+    bool createTablePropModes();
     bool populatePropagationModes();
 
+    bool recreateContestData();
+    bool recreateSupportedContest();
+    bool createTableContest();
+    bool createTableSupportedContest();
+    bool populateContestData();
+
+    bool populateTableSupportedContest();
+
     bool howManyQSOsInLog(const int i);
-    void showError();
+    //void showError();
+
+
 
     //bool moveFromModeIdToSubmodeId();
     bool updateModeIdFromSubModeId();
@@ -137,16 +203,22 @@ private:
     bool updateBandIdTableAward(const int _db);
     bool updateModeIdTableAward(const int _db);
 
+    void queryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+
+
     bool created;
     float dbVersion;    // The current version of the DB. May differ from latestReaded if we are updating the DB!
+    QString dbConnectionName;
     QString softVersion;
     float latestReaded; // The latest version of DB readed in the DB itself
-    bool inMemoryOnly; // The DB is to be created in memory, no file support... Faster but less safe!
-    QDateTime date;
+    //bool inMemoryOnly; // The DB is to be created in memory, no file support... Faster but less safe!
+    //QDateTime date;
     QHash<QString, int> bandIDHash;
     QHash<QString, int> modeIDHash;
+    QHash<QString, int> subModeIDHash;
     QHash<int, QString> IDBandHash;
     QHash<int, QString> IDModeHash;
+    QHash<int, QString> IDSubModeHash;
     QHash<int, QString> freqBandIdHash;
 
     QMap<QString, int> bandQMap;
@@ -155,6 +227,16 @@ private:
     Utilities *util;
 
     QSqlDatabase db;
+    QString dbDir, dbName;
+
+    QStringList insertPreparedQueries, insertQueryFields;
+    QSqlQuery preparedQuery;
+
+    int constrid; // Just an id for the constructor to check who is being executed at one specific time
+
+signals:
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+
 
 };
 
