@@ -24,7 +24,7 @@
  *                                                                           *
  *****************************************************************************/
 
-
+//#include <QDebug>
 #include "dataproxy.h"
 
 
@@ -33,14 +33,33 @@ DataProxy::DataProxy()
    //qDebug() << "DataProxy::DataProxy"  << endl;
 }
 
-
 DataProxy::~DataProxy()
 {
 }
 
+QString DataProxy::getSoftVersion()
+{
+    return QString();
+}
+bool DataProxy::reconnectDB()
+{
+    return false;
+}
+
+QString DataProxy::getDBVersion()
+{
+    return QString();
+}
+
 void DataProxy::createLogModel(){}
 void DataProxy::createLogPanel(){}
 bool DataProxy::haveAtLeastOneLog(){return true;}
+//QStringList DataProxy::getColumnNamesFromTable(const QString _tableName){return QStringList();}
+QStringList DataProxy::getColumnNamesFromTableLog(){return QStringList();}
+
+bool DataProxy::setDXCCAwardStatus(const int _qsoId){return false;}
+
+bool DataProxy::setWAZAwardStatus(const int _qsoId){return false;}
 
 int DataProxy::getIdFromModeName(const QString& _modeName)
 {
@@ -62,10 +81,6 @@ int DataProxy::getModeIdFromSubModeId(const int _sm)
     return -1;
 }
 
-QString DataProxy::getModeFromSubMode (const QString _sm)
-{
-    return "";
-}
 
 bool DataProxy::isModeDeprecated (const QString _sm)
 {
@@ -108,6 +123,11 @@ int DataProxy::getBandIdFromFreq(const double _n)
     return -1;
 }
 
+QString DataProxy::getBandNameFromFreq(const double _n)
+{
+    return QString();
+}
+
 double DataProxy::getLowLimitBandFromBandName(const QString _sm)
 {
     return -1.0;
@@ -118,6 +138,10 @@ double DataProxy::getLowLimitBandFromBandId(const QString _sm)
     return -1.0;
 }
 
+bool DataProxy::isThisFreqInBand(const QString b, const QString fr)
+{
+    return false;
+}
 
 QStringList DataProxy::getBands()
 {
@@ -160,6 +184,17 @@ QStringList DataProxy::getModesInLog(const int _log)
     return QStringList();
 }
 
+int DataProxy::getMostUsedBand(const int _log)
+{
+    return -1;
+}
+
+int DataProxy::getMostUsedMode(const int _log)
+{
+    return -1;
+}
+
+
 int DataProxy::getLastQSOid()
 {
     return -1;
@@ -228,6 +263,26 @@ bool DataProxy::isQSLSent(const int _qsoId)
     return false;
 }
 
+int DataProxy::getBandFromId(const int _qsoId)
+{
+    return -1;
+}
+
+int DataProxy::getModeFromId(const int _qsoId)
+{
+    return -1;
+}
+
+int DataProxy::getDXCCFromId(const int _qsoId)
+{
+    return -1;
+}
+
+int DataProxy::getCQZFromId(const int _qsoId)
+{
+    return -1;
+}
+
 QString DataProxy::getCallFromId(const int _qsoId)
 {
     return "";
@@ -263,8 +318,15 @@ QString DataProxy::getQSLViaFromQRZ(const QString _call)
     return QString();
 }
 
+bool DataProxy::updateAwardDXCC()
+{
+    return false;
+}
 
-
+bool DataProxy::updateAwardWAZ()
+{
+    return false;
+}
 bool DataProxy::deleteQSO(const int _qsoId)
 {
     return false;
@@ -281,6 +343,11 @@ bool DataProxy::isThisQSODuplicated(const QString _qrz, const QString _date, con
 }
 
 
+int DataProxy::getDuplicatedQSOId(const QString _qrz, const QString _date, const QString _time, const int _band, const int _mode)
+{
+    return -1;
+}
+
 bool DataProxy::isDXCCConfirmed(const int _dxcc, const int _currentLog)
 {
     return false;
@@ -301,6 +368,12 @@ bool DataProxy::isVHF(const int _band)
     return false;
 }
 
+bool DataProxy::isUHF(const int _band)
+{
+    return false;
+}
+
+
 QStringList DataProxy::getOperatingYears(const int _currentLog)
 {
     return QStringList();
@@ -311,10 +384,31 @@ void DataProxy::compressDB()
 
 }
 
+bool DataProxy::unMarkAllQSO()
+{
+    return false;
+}
+
+bool DataProxy::lotwSentQueue(const QString _updateDate, const int _currentLog)
+{// Mark LOTW QSL SENT as Q (Queued)
+    return false;
+}
+
+bool DataProxy::lotwSentYes(const QString _updateDate, const int _currentLog, const QString _station)
+{
+    return false;
+}
+
+int DataProxy::getQSOonYear(const int _year, const int _logNumber)
+{
+    return -1;
+}
+
 int DataProxy::getDXCConYear(const int _year, const int _logNumber)
 {
     return -1;
 }
+
 int DataProxy::getCQzonYear(const int _year, const int _logNumber)
 {
     return -1;
@@ -353,6 +447,36 @@ QStringList DataProxy::getSatellitesList()
     return QStringList();
 }
 
+QString DataProxy::getSatelliteUplink(const QString _sat)
+{
+    return QString();
+}
+
+QString DataProxy::getSatelliteDownlink(const QString _sat)
+{
+    return QString();
+}
+
+QStringList DataProxy::getQSLRcvdList()
+{
+    return QStringList();
+}
+
+QStringList DataProxy::getQSLSentList()
+{
+    return QStringList();
+}
+
+QStringList DataProxy::getClubLogStatusList()
+{
+    return QStringList();
+}
+
+QStringList DataProxy::getQSLViaList()
+{
+    return QStringList();
+}
+
 QStringList DataProxy::getValidCatOptions(const int _currentCat, const int _lowerCa)
 {
     return QStringList();
@@ -376,6 +500,32 @@ QString DataProxy::getStationCallSignFromLog(const int _log)
     return QString();
 }
 
+QStringList DataProxy::getStationCallSignsFromLog(const int _log)
+{
+    return QStringList();
+}
+
+QString DataProxy::getOperatorsFromLog(const int _log)
+{
+    return QString();
+}
+
+QString DataProxy::getCommentsFromLog(const int _log)
+{
+    return QString();
+}
+
+QString DataProxy::getLogDateFromLog(const int _log)
+{
+    return QString();
+}
+
+QString DataProxy::getLogTypeNFromLog(const int _log)
+{
+    return QString();
+}
+
+
 int DataProxy::getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo)
 {
     return -1;
@@ -385,11 +535,41 @@ QStringList DataProxy::getDataFromContestType(const int _n)
     return QStringList();
 }
 
+int DataProxy::getLogTypeNumber(const QString _logType)
+{
+    return -1;
+}
+
+QString DataProxy::getLogTypeName(const int _logType)
+{
+    return QString();
+}
+
+QString DataProxy::getLogTypeOfUserLog(const int _logN)
+{
+    return QString();
+}
+
+int DataProxy::getLogNumberFromQSOId(const int _qsoId)
+{
+    return -1;
+}
+
+bool DataProxy::fillEmptyDXCCInTheLog()
+{
+    return false;
+}
+
 int DataProxy::getHowManyQSOInLog(const int _log)
 {
     return 0;
 }
 
+int DataProxy::getHowManyConfirmedQSLInLog(const int _log)
+{
+    return 0;
+}
+
 bool DataProxy::addNewLog (const QStringList _qs)
 {
     return false;
@@ -495,6 +675,11 @@ int DataProxy::getHowManyEntities()
     return -1;
 }
 
+int DataProxy::getMaxEntityID()
+{
+    return -1;
+}
+
 bool DataProxy::updateISONames()
 {
     return false;
@@ -504,3 +689,25 @@ QString DataProxy::getISOName(const int _n)
 {
     return QString();
 }
+
+void DataProxy::getFoundInLog(const QString _txt, const int _log)
+{
+    //return false;
+}
+/*
+bool DataProxy::queryPrepare(const QString _query)
+{
+    return false;
+}
+
+bool DataProxy::queryBind(const QString _field, const QString value)
+{
+    return false;
+}
+
+
+ bool DataProxy::queryExec()
+{
+    return false;
+}
+*/
