@@ -27,20 +27,30 @@
  *****************************************************************************/
 #include <QString>
 #include <QStringList>
+#include <QObject>
+//#include <QtGlobal>
 
 #include "dataproxy.h"
 #include "database.h"
 
+
 class DataProxy_SQLite : public DataProxy {
+    Q_OBJECT
 
 public:
-    DataProxy_SQLite();
+    DataProxy_SQLite(const QString _softVersion, const QString _parentFunction);
     ~DataProxy_SQLite();
 
+    QString getSoftVersion();
+    QString getDBVersion();
+    bool reconnectDB();
+
     void createLogModel();
     void createLogPanel();
     bool haveAtLeastOneLog();
 
+    QStringList getColumnNamesFromTableLog();
+
     int getIdFromModeName(const QString& _modeName);
     int getIdFromBandName(const QString& _bandName);
     int getSubModeIdFromSubMode(const QString _subModeName);
@@ -53,25 +63,31 @@ public:
     QStringList getModesIDs();
     QStringList getBandsInLog(const int _log);
     QStringList getModesInLog(const int _log);
+    int getMostUsedBand(const int _log);
+    int getMostUsedMode(const int _log);
 
     QString getNameFromBandId (const int _id);
     QString getNameFromModeId (const int _id);
     QString getNameFromSubModeId (const int _id);
+
     QString getSubModeFromId (const int _id);
     QString getNameFromSubMode (const QString _sm); // Checks if a submode is deprecated TODO: CHeck if really needed
-    QString getModeFromSubMode (const QString _sm);
+    //QString getNameFromSubMode (const QString _sm); // DEPRECATED
     bool isModeDeprecated (const QString _sm);
 
     QString getFreqFromBandId(const int _id);
     int getBandIdFromFreq(const double _n);
+    QString getBandNameFromFreq(const double _n);
     double getLowLimitBandFromBandName(const QString _sm);
     double getLowLimitBandFromBandId(const QString _sm);
+    bool isThisFreqInBand(const QString b, const QString fr);
 
     int getLastQSOid();
 
     bool deleteQSO(const int _qsoId);
     int isWorkedB4(const QString _qrz, const int _currentLog);
     bool isThisQSODuplicated(const QString _qrz, const QString _date, const QString _time, const int _band, const int _mode);
+    int getDuplicatedQSOId(const QString _qrz, const QString _date, const QString _time, const int _band, const int _mode);
     bool isDXCCConfirmed(const int _dxcc, const int _currentLog);
     bool isQSLReceived(const int _qsoId);
     bool isQSLSent(const int _qsoId);
@@ -89,8 +105,12 @@ public:
     bool isHF(const int _band);
     bool isWARC(const int _band);
     bool isVHF(const int _band);
+    bool isUHF(const int _band);
 
-
+    int getBandFromId(const int _qsoId);
+    int getModeFromId(const int _qsoId);
+    int getDXCCFromId(const int _qsoId);
+    int getCQZFromId(const int _qsoId);
     QString getCallFromId(const int _qsoId);
     QStringList getClubLogRealTimeFromId(const int _qsoId);
     // Complete with previous
@@ -101,6 +121,12 @@ public:
     QString getQSLViaFromQRZ(const QString _call);
     // /Complete with previous
 
+    bool updateAwardDXCC();
+    bool updateAwardWAZ();
+
+
+    //LOTW
+
     int getContinentIdFromContinentShortName(const QString _n);
     QString getContinentShortNameFromEntity(const int _n);
     int getContinentIdFromEntity(const int _n);
@@ -121,12 +147,17 @@ public:
     QString getEntityPrefixes(const int _enti);
     QStringList getEntitiesNames();
     int getHowManyEntities();
+    int getMaxEntityID();
 
     QStringList getOperatingYears(const int _currentLog);
     void compressDB();
+    bool unMarkAllQSO();            // Unmarks all the marked QSO
+    bool lotwSentQueue(const QString _updateDate, const int _currentLog);          // Mark LOTW QSL SENT as Q (Queued)
+    bool lotwSentYes(const QString _updateDate, const int _currentLog, const QString _station);         // Update LOTW QSL SENT marked as Q as Y (Queued)
 
     bool clearLog();
 
+    int getQSOonYear(const int _year, const int _logNumber);
     int getDXCConYear(const int _year, const int _logNumber);
     int getCQzonYear(const int _year, const int _logNumber);
     bool newDXMarathon(const int _dxcc, const int _cq, const int _year, const int _logNumber);
@@ -136,30 +167,71 @@ public:
     QStringList getContestOverlays();
     int getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo);
     QStringList getDataFromContestType(const int _n);
+    int getLogTypeNumber(const QString _logType);
+    QString getLogTypeName(const int _logType);
+    QString getLogTypeOfUserLog(const int _logN);
+    int getLogNumberFromQSOId(const int _qsoId);
 
     QStringList getBandNames();
     QStringList getPropModeList();
-    QStringList getSatellitesList();
+    QStringList getSatellitesList();   
+    QString getSatelliteUplink(const QString _sat);
+    QString getSatelliteDownlink(const QString _sat);
+    QStringList getQSLRcvdList();
+    QStringList getQSLSentList();
+    QStringList getClubLogStatusList();
+    QStringList getQSLViaList();
 
     QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
 
+    bool fillEmptyDXCCInTheLog();
     int getHowManyQSOInLog(const int _log);
+    int getHowManyConfirmedQSLInLog(const int _log);
     int getNumberOfManagedLogs();
     QStringList getListOfManagedLogs();
     int getMaxLogNumber();
     QString getStationCallSignFromLog(const int _log);
+    QStringList getStationCallSignsFromLog(const int _log);
+    QString getOperatorsFromLog(const int _log);
+    QString getCommentsFromLog(const int _log);
+    QString getLogDateFromLog(const int _log);
+    QString getLogTypeNFromLog(const int _log);
     bool addNewLog (const QStringList _qs);
     bool doesThisLogExist(const int _log);
 
     bool updateISONames(); // Update the entities ISO names for the flags
     QString getISOName(const int _n);
+    bool setDXCCAwardStatus(const int _qsoId);
+    bool setWAZAwardStatus(const int _qsoId);
+
+
+
+    void getFoundInLog(const QString _txt, const int _log=-1);
+
+    //bool queryPrepare(const QString _query);
+    //bool queryBind(const QString _field, const QString value);
+    //bool queryExec();
 
 private:
     bool dbCreated;
     DataBase *db;
     QStringList sortBandIdBottonUp(const QStringList _qs);
+    double getFreqFromRange(QString _fr); //May even receive: 145.900-146.00 and should return the mid in the range (145.950)
+    QStringList getColumnNamesFromTable(const QString _tableName);
+
+    int getPrefixId(const QString _qrz);
+    QString changeSlashAndFindPrefix(const QString _qrz);
+
+    bool searching;
+    int executionN;
+    Utilities *util;
+    //QSqlQuery preparedQuery;
     //QSqlRelationalTableModel *logModel;
 
+signals:
+    void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+
 };
 
 #endif // DATAPROXY_SQLITE_H
