@@ -5,12 +5,12 @@
 #include <QFile>
 //#include <QDebug>
 
-DownLoadCTY::DownLoadCTY(const QString _kontestDir, const QString _klogVersion) : QObject(0)
+DownLoadCTY::DownLoadCTY(const QString _klogDir, const QString _klogVersion) : QObject(0)
 {    
-   //qDebug() << "DownLoadCTY::DownLoadCTY(): " << _kontestDir << endl;
+   //qDebug() << "DownLoadCTY::DownLoadCTY(): " << _klogDir << endl;
     util = new Utilities;
     url = new QUrl;
-    kontestDir = _kontestDir;
+    klogDir = _klogDir;
     result = -1;  // Error unknown
 
     manager = new QNetworkAccessManager;
@@ -30,7 +30,7 @@ DownLoadCTY::DownLoadCTY(const QString _kontestDir, const QString _klogVersion)
     //qDebug() << "DownLoadCTY::DownLoadCTY() - UserAgent: " <<  request->rawHeader("QNetworkRequest::UserAgentHeader") << endl;
 
     QObject::connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
-
+    //qDebug() << "DownLoadCTY::DownLoadCTY(): - END"  << endl;
 }
 
 DownLoadCTY::~DownLoadCTY()
@@ -61,7 +61,7 @@ DownLoadCTY::~DownLoadCTY()
        //errorCode = query.lastError().number();
 
        msgBox.setIcon(QMessageBox::Warning);
-       aux = tr("Download of the CTY.CSV failed with the following error code: ");
+       aux = tr("Download of cty.csv failed with the following error code: ");
        msgBox.setText(aux + reply->errorString());
        msgBox.setStandardButtons(QMessageBox::Ok);
        msgBox.setDefaultButton(QMessageBox::Ok);
@@ -73,7 +73,7 @@ DownLoadCTY::~DownLoadCTY()
        if (saveToDisk(filename, reply))
        {
            msgBox.setIcon(QMessageBox::Information);
-           aux = tr("Download of the CTY.CSV done.");
+           aux = tr("Download of cty.csv done.");
            msgBox.setText(aux);
            msgBox.setStandardButtons(QMessageBox::Ok);
            msgBox.setDefaultButton(QMessageBox::Ok);
@@ -144,7 +144,7 @@ QString DownLoadCTY::saveFileName(const QUrl &url)
     if (QFile::exists(basename)) {
 
         msgBox.setIcon(QMessageBox::Warning);
-        aux = tr("There is already a CTY.CSV file in the folder but it will be replaced with the new one.");
+        aux = tr("There is already a cty.csv file in the folder but it will be replaced with the new one.");
         msgBox.setText(aux);
         msgBox.setStandardButtons(QMessageBox::Ok);
         msgBox.setDefaultButton(QMessageBox::Ok);
