@@ -25,46 +25,24 @@ email                : jaime@robles.es
 *****************************************************************************/
 #include "dxcluster.h"
 
-DXClusterWidget::DXClusterWidget(QWidget *parent)
+DXClusterWidget::DXClusterWidget(DataProxy *dp, QWidget *parent)
           : QWidget(parent)
 {
     //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
-    awards = new Awards();
-    dataProxy = new DataProxy();
+    dataProxy = dp;
+    constrid = 1;
+    awards = new Awards(dataProxy);
+
 
     initClass();
-    //TESTADDSPOT();
+    //qDebug() << "DXClusterWidget::DXClusterWidget - END" << endl;
 }
 
-void DXClusterWidget::initClass()
-{
-    dxClusterConnected = false;
-    dxClusterAlreadyConnected = false;
-
-    showhf = true;
-    showvhf = true;
-    showwarc = true;
-    showworked = true;
-    showconfirmed = true;
-    showann = true;
-    showwwv = true;
-    showwcy = true;
-    myQrz = QString();
-    currentLog = 0;
-}
-
-void DXClusterWidget::setMyQRZ(const QString _qrz)
-{
-    if (_qrz.length()>2)
-    {
-        myQrz = _qrz;
-    }
-
-}
-DXClusterWidget::DXClusterWidget(const QString &clusterToConnect, const int portToConnect, QWidget *parent)
+DXClusterWidget::DXClusterWidget(DataProxy *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
           : QWidget(parent)
 {
-   //qDebug() << "DXClusterWidget::DXClusterWidget" << clusterToConnect << QString::number(portToConnect) << endl;
+   //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << endl;
+   constrid = 2;
 
     initClass();
     server = clusterToConnect;
@@ -76,10 +54,10 @@ DXClusterWidget::DXClusterWidget(const QString &clusterToConnect, const int port
     //workedColor.setNamedColor("slategrey");
     //confirmedColor.setNamedColor("slategrey");
     //newOneColor.setNamedColor("slategrey");
+    dataProxy = dp;
+    world = new World(dataProxy);
+    awards = new Awards(dataProxy);
 
-    world = new World();
-    awards = new Awards();
-    dataProxy = new DataProxy_SQLite();
 
     tcpSocket = new QTcpSocket(this);
 
@@ -121,13 +99,57 @@ DXClusterWidget::DXClusterWidget(const QString &clusterToConnect, const int port
     addData();
 
      //TESTADDSPOT();
+    //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << endl;
 
 }
+
+void DXClusterWidget::initClass()
+{
+    dxClusterConnected = false;
+    dxClusterAlreadyConnected = false;
+
+    showhf = true;
+    showvhf = true;
+    showwarc = true;
+    showworked = true;
+    showconfirmed = true;
+    showann = true;
+    showwwv = true;
+    showwcy = true;
+    myQrz = QString();
+    currentLog = 0;
+}
+
+void DXClusterWidget::setMyQRZ(const QString _qrz)
+{
+    if (_qrz.length()>2)
+    {
+        myQrz = _qrz;
+    }
+
+}
+
 void DXClusterWidget::addData()
 {
     //qDebug() << "DXClusterWidget::addData " << endl;
+
+    /*
+                QTreeWidgetItem *item = new QTreeWidgetItem(searchResultsTreeWidget);
+                i = world->getQRZARRLId(_call);
+                aux = world->getEntityName(i) + " - CQ: " + QString::number(world->getEntityCqz(i));
+                item->setToolTip(0, aux);
+                item->setToolTip(1, aux);
+                item->setToolTip(2, aux);
+                item->setToolTip(3, aux);
+                item->setToolTip(4, aux);
+                item->setToolTip(5, aux);
+                item->setToolTip(6, aux);
+*/
+
+
     dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Click on connect to connect to the DX-Cluster"), awards->getDefaultColor());
 
+
 }
 
 DXClusterWidget::~DXClusterWidget()
@@ -184,7 +206,7 @@ void DXClusterWidget::connectToDXCluster()
     tcpSocket->connectToHost( server, port );
     dxClusterListWidget->setSortingEnabled (false);
 
-    dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Trying to connect to the server\n"), awards->getDefaultColor());
+    dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Trying to connect to the server") + "\n", awards->getDefaultColor());
 }
 
 
@@ -196,8 +218,8 @@ void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socke
          break;
      case QAbstractSocket::HostNotFoundError:
          QMessageBox::warning(this, tr("KLog DXCluster"),
-                                  tr("The host was not found. Please check:\n\n"
-                                     "- your network connection;\n"
+                                  tr("The host was not found. Please check:") + "\n\n" +
+                                     tr ("- your network connection;\n"
                                      "- the host name and port settings."));
          break;
      case QAbstractSocket::ConnectionRefusedError:
@@ -215,12 +237,12 @@ void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socke
 
  }
 
-bool DXClusterWidget::checkIfNeedsToBePrinted(const QString _dxCall, int const _band, const int _mode)
+bool DXClusterWidget::checkIfNeedsToBePrinted(const QString _DXEntity, int const _band, const int _mode)
 {
     //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _dxCall << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
     QStringList qs;
     qs.clear();
-    qs << _dxCall << QString::number(_band) << QString::number(_mode)  << QString::number(currentLog);
+    qs << _DXEntity << QString::number(_band) << QString::number(_mode)  << QString::number(currentLog);
     //bool isConfirmed = false;
     bool status = awards->isThisSpotConfirmed (qs);
 
@@ -310,7 +332,7 @@ void DXClusterWidget::slotClusterDataArrived()
     QString dxFrequency;
     QString spotBand;
     spotBand = "-1";
-    bool isADXSpot = false;
+    //bool isADXSpot = false;
     int dxEntity = -1;
 
     while ( tcpSocket->canReadLine() ) {
@@ -328,22 +350,23 @@ void DXClusterWidget::slotClusterDataArrived()
         if ((tokens[0] == "DX") && (tokens[1] == "de"))
         {
            //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << endl;
-            isADXSpot = true;
+            //isADXSpot = true;
             QString spotter = tokens[2];
             spotter.truncate(spotter.size() - 1);
             dxFrequency = tokens[3];
             // Convert KHz to MHz...
             //dxFrequency = QString::number(abs (dxFrequency.toFloat())/1000);
             dxFrequency = QString::number( (dxFrequency.toFloat())/1000);
+            dxCall = tokens[4];
             dxEntity = world->getQRZARRLId(dxCall);
             //
             spotBand = QString::number(dataProxy->getBandIdFromFreq(  dxFrequency.toDouble()  ) );
 
-            dxCall = tokens[4];
+
             qs.clear();
             //spotBand = QString::number(world->getBandIdFromFreq(  dxFrequency  ) );
-            qs << dxCall << spotBand << "-1" << QString::number(currentLog) ;
-
+            qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
+            //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << endl;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
 
             if (awards->isDXMarathonNeed(dxEntity, world->getQRZCqz(dxCall), QDateTime::currentDateTime().date().year(), currentLog))
@@ -365,17 +388,18 @@ void DXClusterWidget::slotClusterDataArrived()
           //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << endl;
           //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << endl;
 
-            isADXSpot = true;
+            //isADXSpot = true;
             dxCall = tokens[1];
             dxFrequency = tokens[0];
             dxFrequency = QString::number( (dxFrequency.toFloat())/1000);
 
             qs.clear();
             spotBand = QString::number(dataProxy->getBandIdFromFreq(  dxFrequency.toDouble()  ) );
-            qs << dxCall << spotBand << "-1" << QString::number(currentLog) ;
             dxEntity = world->getQRZARRLId(dxCall);
-
+            //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << endl;
+            qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
+
             if (awards->isDXMarathonNeed(dxEntity, world->getQRZCqz(dxCall), QDateTime::currentDateTime().date().year(), currentLog))
             {
                 dxClusterString = dxClusterString + "  ### Needed for DXMarathon - " + QString::number(QDateTime::currentDateTime().date().year()) + " ###";
@@ -395,7 +419,7 @@ void DXClusterWidget::slotClusterDataArrived()
         //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << endl;
         //dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, dxClusterString, dxSpotColor);
         //TODO: Change the "-1" by the mode
-        if (!checkIfNeedsToBePrinted(dxCall, spotBand.toInt(), -1))
+        if (!checkIfNeedsToBePrinted(QString::number(dxEntity), spotBand.toInt(), -1))
         {
            //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << endl;
             return;
@@ -480,7 +504,7 @@ void DXClusterWidget::slotClusterSocketConnected()
             clearButton->setText(tr("Clear"));
             dxClusterAlreadyConnected = true;
         } else {
-            os << tr("Not logged on, you may to enter your callsign again.") << "\n";
+            os << tr("Not logged on, you may need to enter your callsign again.") << "\n";
             dxClusterAlreadyConnected = false;
         }
         inputCommand->setEnabled(true);
