@@ -51,11 +51,21 @@
 #include "mainwindowmydatatab.h"
 #include "mainwindowinputcomment.h"
 #include "mainwindowinputothers.h"
+#include "mainwindowinputeqsl.h"
+#include "mainwindowinputqsl.h"
 #include "elogclublog.h"
 #include "utilities.h"
 #include "downloadcty.h"
 #include "dxccstatuswidget.h"
 #include "softwareupdate.h"
+#include "logmodel.h"
+#include "logwindow.h"
+#include "searchwidget.h"
+#include "infowidget.h"
+#include "showerrordialog.h"
+
+
+
 
 class QTimer;
 class QDateTime;
@@ -98,6 +108,7 @@ enum
 
 enum
 {
+    DX = 0,
     NoContest = 0,
     CQ_WW_SSB = 1,
     CQ_WW_CW = 2,
@@ -112,25 +123,40 @@ class MainWindow : public  QMainWindow
     Q_OBJECT
 
 public:
-    MainWindow(const QString _kontestDir, const QString tversion);
+    MainWindow(const QString _klogDir, const QString tversion);
+     ~MainWindow();
 
 private slots:
-
+    //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+    void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString queryFailed);
     void slotQRZReturnPressed();
     void slotQRZSpacePressed();
     void slotQRZTextChanged();
     void slotSRXTextChanged();
     void slotSTXTextChanged();
+    void slotUpdateLocator(QString _loc);
     void slotLocatorTextChanged();
     void slotMyLocatorTextChanged();
+    void slotFreqTXChanged();
+    void slotFreqRXChanged();
 
     void slotSearchBoxTextChanged();
-    void slotSearchExportButtonClicked();
-    void slotSearchBoxSelectAllButtonClicked();
-    void slotSearchClearButtonClicked();
-    void slotSearchBoxSelectionChanged();
-    void slotSearchBoxReSearchButtonClicked();
-    //void slotSearchBoxOnItemChanged( QTreeWidgetItem * item, int column);
+    void slotSearchToolNeededQSLToSend();
+    void slotToolSearchRequestedQSLToSend();
+    void slotToolSearchNeededQSLPendingToReceive();
+    void slotToolSearchNeededQSLRequested();
+    void slotToolLoTWMarkAllQueuedThisLog();
+    void slotToolLoTWMarkAllQueued();
+    void slotToolLoTWMarkAllYesThisLog();
+    void slotToolLoTWMarkAllYes();
+    //void slotSearchExportButtonClicked();
+    //void slotSearchBoxSelectAllButtonClicked();
+    //void slotSearchClearButtonClicked();
+    //void slotSearchBoxSelectionChanged();
+    //void slotSearchBoxReSearchButtonClicked();
+
+    //void showMenuRightButtonSearchCreateActions();
+    //void righButtonSearchMenu(const int trow);
 
     void slotModeComboBoxChanged();
     void slotBandComboBoxChanged();
@@ -139,55 +165,56 @@ private slots:
     void slotOKButtonClicked();
     void slotSpotItButtonClicked();
     void slotClearButtonClicked();
+    void slotRefreshDXCCWidget();
     void slotUpdateTime();
     void slotLogWinShow();
+    void slotLogRefresh();
     void slotScoreWinShow();
+    void slotQSODelete(const int _id);
+
+    void slotShowAwards();
+    void slotUpdateStatusBar(const QString statusm);
+
     void slotSetup(const int _page=0);
-    void slotQsoDeleteFromLog();
-    void slotQSLSentViaBureauFromLog();
-    void slotQSLSentViaDirectFromLog();
-    void slotQSLRecViaDirectFromLog();
-    void slotQSLRecViaBureauFromLog();
-    void slotQSOToEditFromLog();
 
-    void slotQsoDeleteFromSearch();
-    void slotQSLSentViaBureauFromSearch();
-    void slotQSLSentViaDirectFromSearch();
-    void slotQSLSentViaDirectMarkDXReqFromSearch();
+    //void slotQsoDeleteFromSearch();
+    //void slotQSLSentViaBureauFromSearch();
+    //void slotQSLSentViaDirectFromSearch();
+    //void slotQSLSentViaDirectMarkDXReqFromSearch();
 
-    void slotQSLSentViaBureuMarkDXReqFromSearch();
-    void slotQSLRecViaDirectFromSearch();
-    void slotQSLRecViaBureauFromSearch();
-    void slotQSLRecViaDirectMarkReqFromSearch();
-    void slotQSLRecViaBureauMarkReqFromSearch();
-    void slotQSLSentMarkAsRequested();
-    void slotQSLRecMarkAsRequested();
-    void slotQSOToEditFromSearch();
+    //void slotQSLSentViaBureuMarkDXReqFromSearch();
+    //void slotQSLRecViaDirectFromSearch();
+    //void slotQSLRecViaBureauFromSearch();
+    //void slotQSLRecViaDirectMarkReqFromSearch();
+    //void slotQSLRecViaBureauMarkReqFromSearch();
+    //void slotQSLSentMarkAsRequested();
+    //void slotQSLRecMarkAsRequested();
+    //void slotQSOToEditFromSearch();
 
     void slotrstTXTextChanged();
     void slotrstRXTextChanged();
     void slotADIFExport();
+    void slotLoTWImport();
+    void slotLoTWExport();
     void slotADIFExportAll();
     void slotADIFImport();
     void slotRQSLExport();
     void slotCabrilloExport();
-    void slotQSLRecvComboBoxChanged();
-    void slotQSLSentComboBoxChanged();
-    void sloteQSLRecvComboBoxChanged();
-    void sloteQSLSentComboBoxChanged();
-    void slotLotwRecvComboBoxChanged();
-    void slotLotwSentComboBoxChanged();
-    void slotQSLViaTextChanged();
+    //void slotQSLViaTextChanged();
+
+
+//TODO: REMOVE EQSL
+    //void slotQSLRecvComboBoxChanged();
+    //void slotQSLSentComboBoxChanged();
+    //void sloteQSLRecvComboBoxChanged();
+    //void sloteQSLSentComboBoxChanged();
+    //void slotLotwRecvComboBoxChanged();
+    //void slotLotwSentComboBoxChanged();
 
     void slotSetPropMode(const QString _p);
-
+    void slotFillEmptyDXCCInTheLog();
     void slotUpdateCTYDAT();
     void slotWorldReload();
-    void slotToolSearchNeededQSLToSend();
-    void slotToolSearchRequestedQSLToSend();
-    void slotToolSearchNeededQSLPendingToReceive();
-    void slotToolSearchNeededQSLRequested();
-    void slotToolSearchQSL(const int actionQSL);
 
     void slotExitFromSlotDialog(const int exitID);
 
@@ -201,8 +228,6 @@ private slots:
     bool saveFileAs();
     bool slotOpenKLogFolder();
 
-
-
     void slotFilePrint();
     //void slotFileClose();
 
@@ -211,17 +236,22 @@ private slots:
     void slotHelpCheckUpdatesAction();
     void slotAboutQt();
        
-
-    // logpanel
-    void slotRighButtonFromLog( const QPoint& pos);
-    void slotDoubleClickLog( const QModelIndex & index);
-    void slotDoubleClickSearch( QTreeWidgetItem* item, int); // Double click on a QSO in the search box
-
     void slotRecalculateAwardsButtonClicked();
 
+    // logpanel
+    //void slotRighButtonFromLog( const QPoint& pos);
+    void slotDoubleClickLog( const int _qsoID);
+    //void slotDoubleClickLog( const QModelIndex & index);
+
+    //SEARCH    
+    void slotShowSearchWidget();                // The SearchWidget request being shown
+    //void slotDoubleClickSearch( QTreeWidgetItem* item, int); // Double click on a QSO in the search box
+    //void slotRighButtonSearch(const QPoint& pos);
+    //void slotToolSearchNeededQSLToSend();
+    //void slotToolSearchNeededQSLPendingToReceive();
+    //void slotToolSearchNeededQSLRequested();
+    //void slotToolSearchQSL(const int actionQSL);
     //SEARCH
-    void slotRighButtonSearch(const QPoint& pos);
-    ///SEARCH
 
     // CLUSTER
     void slotAnalyzeDxClusterSignal(const QStringList _qs);
@@ -235,6 +265,13 @@ private slots:
 
     void slotShowSoftUpdateResults(const bool _b);   // Software Update: Receives the signal to see if it is needed or not to update
 
+    //SATELLITE
+    void slotSatBandTXComboBoxChanged(const QString _q);
+
+    void slotDefineNewBands(const QStringList _bands);
+    void slotChangeRXFreq(const QString _f);
+    void slotChangeTXFreq(const QString _f);
+	
 private:
     bool maybeSave();
 
@@ -268,33 +305,25 @@ private:
     void createActionsCommon();
     void createActionsCQWW();
     void createActionsDX();
-    void createlogPanel();
-    void createlogModel(const int _i);
+    //void createlogPanel();
+    //void createlogModel(const int _i);
 
     void createScorePanel();
-    void createSearchResultsPanel();
+    //void createSearchResultsPanel();
 
     void initialContestModeConfiguration();
 
-    void createKeyEvents();
-    void updateStatusBar(const QString statusm);
+    //void createKeyEvents();
+
 
     bool readCtyFile();
 
 
-    void showMenuRightButtonFromLogCreateActions();
-    void righButtonFromLogMenu(const int trow);
 
-    void showMenuRightButtonSearchCreateActions();
-    void righButtonSearchMenu(const int trow);
+    //void righButtonFromLogMenu(const int trow);
 
-    void qslSentViaBureau(const int _qsoId);
-    //void qslSentViaDirect(const int _qsoId);
-    void qslRecViaBureau(const int _qsoId);
-    void qslRecViaDirect(const int _qsoId);
-
-    void qslRecViaBureauMarkReq(const int _qsoId);
-    void qslRecViaDirectMarkReq(const int _qsoId);
+    //void qslRecViaBureauMarkReq(const int _qsoId);
+    //void qslRecViaDirectMarkReq(const int _qsoId);
 
     bool isQSLReceived(const int _qsoId);
     bool isQSLSent(const int _qsoId);
@@ -322,6 +351,7 @@ private:
     bool processConfigLine(const QString _line);
     void readConfigData();    
     void defineStationCallsign();
+    QString selectStationCallsign();
 
     void checkIfNewBandOrMode();
     void readActiveBands (const QStringList actives);
@@ -329,13 +359,13 @@ private:
 
 
     void qsoToEdit (const int _qso);
-    void showInfoFromLocators(const QString _loc1, const QString _loc2);
-    void clearInfoFromLocators();
+    //void showInfoFromLocators(const QString _loc1, const QString _loc2);
+    //void clearInfoFromLocators();
     void completeWithPreviousQSO(const QString _call);
 
     //void showQRZEntityInfo(const QString _qrz);
-    void showEntityInfo(const int _enti, int _cq=-1, int _itu=-1);
-    QString getStyleColorToLabelFromBand(const QString _b, const QString _q);
+    //void showEntityInfo(const int _enti, int _cq=-1, int _itu=-1);
+    //QString getStyleColorToLabelFromBand(const QString _b, const QString _q);   // Band, Entity
     void showAwards();
     void showDXMarathon(const int _year);
     void updateQSLRecAndSent();
@@ -355,7 +385,7 @@ private:
 
 
     QWidget *mainWidget;
-    QWidget *dxClusterTabWidget, *searchTabWidget;
+    //QWidget *dxClusterTabWidget;//, *searchTabWidget;
     World *world;
     FileManager *filemanager;
     Locator *locator;
@@ -368,24 +398,27 @@ private:
     AboutDialog *aboutDialog;
 
     QPushButton *addButton;
-    QLabel *distShortLabelN;
-    QLabel *distLongLabelN;
-
-    //QLabel distShortLabelN;
-    //QLabel distLongLabelN;
+    //QLabel *distShortLabelN;
+    //QLabel *distLongLabelN;
 
     DXCCStatusWidget *dxccStatusWidget;
-    QSqlRelationalTableModel *logModel;
-    QWidget *logPanel;
-    QTableView *logView;
-    QTreeWidget *searchResultsTreeWidget;
+    //QSqlRelationalTableModel *logModel;
+    //QWidget *logPanel;
+    //QTableView *logView;
+    //QTreeWidget *searchResultsTreeWidget;
     QLabel *logLabel;
 
     QWidget *scoreWindow; //, dxWindow;
     QTextEdit *scoreTextEdit;
 
+    LogModel *logModel;
+    LogWindow *logWindow;
+
+    ShowErrorDialog *showErrorDialog;
+
+
     // <UI>
-    QGroupBox *gridGroupBox, *qrzgroupBox, *searchgroupBox;
+    QGroupBox *gridGroupBox, *qrzgroupBox;//, *searchgroupBox;
     QFrame *dxUpLeftInputFrame;//, *dxUpRightOutputFrame;
 
     QLineEdit *qrzLineEdit, *nameLineEdit, *qthLineEdit, *locatorLineEdit;
@@ -397,15 +430,16 @@ private:
 
     QTabWidget *dxBottonTab, *dxUpLeftTab, *dxUpRightTab;
 
-
     QMenu *fileMenu;
     QMenu *toolMenu;
+    QMenu *qslToolMenu;
+    QMenu *lotwToolMenu;
+    //QMenu *lotwMarkAllAsQueuedMenu;
+    //QMenu *lotwMarkAllInThisLogAsQueuedMenu;
     QMenu *viewMenu;
     QMenu *setupMenu;
     QMenu *helpMenu;
 
-
-
     QAction *klogFolderAct;
     QAction *openAct;
     QAction *saveAct;
@@ -426,38 +460,45 @@ private:
     QAction *ADIFExport;
     QAction *ADIFExportAll;
     QAction *ADIFImport;
+    QAction *LoTWExport;
+    QAction *LoTWImport;
     QAction *ReqQSLExport;
     QAction *CabrilloExport;
     QAction *fillQsoAct;
+    QAction *fillDXCCAct;
     QAction *findQSO2QSLAct;
     QAction *findRequestedQSLAct;
     QAction *findQSLPendingToReceiveAct;
     QAction *findQSLDXRequestedAct;
+    QAction *lotwMarkSentQueuedThisLogAct;
+    QAction *lotwMarkSentQueuedAct;
+    QAction *lotwMarkSentYesThisLogAct;
+    QAction *lotwMarkSentYesAct;
 
     QAction *downloadCTYAct;
 
-
     QAction *loggWinAct;
-
+/*
     QAction *delQSOFromLogAct;
     QAction *qsoToEditFromLogAct; 
     QAction *qslSentViaBureauFromLogAct;
     QAction *qslSentViaDirectFromLogAct;
     QAction *qslRecViaBureauFromLogAct;
     QAction *qslRecViaDirectFromLogAct;
+*/
     QAction *qslSentRequestedAct;
     QAction *qslRecRequestedAct;
 
-    QAction *delQSOFromSearchAct;
-    QAction *qsoToEditFromSearchAct;
-    QAction *qslSentViaBureauFromSearchAct;
-    QAction *qslSentViaDirectFromSearchAct;
-    QAction *qslSentViaDirectMarkRcvReqFromSearchAct;
-    QAction *qslSentViaBureauMarkRcvReqFromSearchAct;
-    QAction *qslRecViaBureauFromSearchAct;
-    QAction *qslRecViaDirectFromSearchAct;
-    QAction *qslRecViaBureauMarkReqFromSearchAct;
-    QAction *qslRecViaDirectMarkReqFromSearchAct;
+    //QAction *delQSOFromSearchAct;
+    //QAction *qsoToEditFromSearchAct;
+    //QAction *qslSentViaBureauFromSearchAct;
+    //QAction *qslSentViaDirectFromSearchAct;
+    //QAction *qslSentViaDirectMarkRcvReqFromSearchAct;
+    //QAction *qslSentViaBureauMarkRcvReqFromSearchAct;
+    //QAction *qslRecViaBureauFromSearchAct;
+    //QAction *qslRecViaDirectFromSearchAct;
+    //QAction *qslRecViaBureauMarkReqFromSearchAct;
+    //QAction *qslRecViaDirectMarkReqFromSearchAct;
 
     QLineEdit *rstTXLineEdit;
     QLineEdit *rstRXLineEdit;
@@ -472,12 +513,12 @@ private:
     //QLabel *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel; //entityPrimLabel
     QLabel *infoLabel1, *infoLabel2;
     //QPushButton *flagIcon; // To paint a flag of the worked entity
-    QLabel *bandLabel1, *bandLabel2, *bandLabel3, *bandLabel4;
-    QLabel *bandLabel5, *bandLabel6, *bandLabel7, *bandLabel8;
-    QLabel *bandLabel9, *bandLabel10, *bandLabel11, *bandLabel12;
-    QLabel *continentLabel, *prefixLabel, *cqzLabel, *ituzLabel;
-    QLabel *gradShortLabel, *distShortLabel;
-    QLabel *gradLongLabel, *distLongLabel;
+    //QLabel *bandLabel1, *bandLabel2, *bandLabel3, *bandLabel4;
+    //QLabel *bandLabel5, *bandLabel6, *bandLabel7, *bandLabel8;
+    //QLabel *bandLabel9, *bandLabel10, *bandLabel11, *bandLabel12;
+    //QLabel *continentLabel, *prefixLabel, *cqzLabel, *ituzLabel;
+    //QLabel *gradShortLabel, *distShortLabel;
+    //QLabel *gradLongLabel, *distLongLabel;
 
     //QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
     QComboBox *operatingYearsComboBox;
@@ -489,32 +530,37 @@ private:
                 *wazConfirmedQLCDNumber, *wazWorkedQLCDNumber,
                 *localConfirmedQLCDNumber, *localWorkedQLCDNumber,
                 *qsoConfirmedQLCDNumber, *qsoWorkedQLCDNumber,
-                *dxMarathonDXCCQLCDNumber, *dxMarathonCQQLCDNumber, *dxMarathonPointsQLCDNumber;
-    QComboBox *eqslSentComboBox, *eqslRecComboBox, *lotwSentComboBox, *lotwRecComboBox, *clublogComboBox;
-    QDateEdit *eqslSentQDateEdit, *eqslRecQDateEdit, *lotwSentQDateEdit, *lotwRecQDateEdit, *clublogQDateEdit;
+                *dxMarathonQSOLCDNumber, *dxMarathonDXCCQLCDNumber, *dxMarathonCQQLCDNumber, *dxMarathonPointsQLCDNumber;
+    //eQSL
+    //QComboBox *eqslSentComboBox, *eqslRecComboBox, *lotwSentComboBox, *lotwRecComboBox, *clublogComboBox;
+    //QDateEdit *eqslSentQDateEdit, *eqslRecQDateEdit, *lotwSentQDateEdit, *lotwRecQDateEdit, *clublogQDateEdit;
 
-    QComboBox *qslSentComboBox, *qslRecComboBox, *qslSentViaComboBox, *qslRecViaComboBox;
-    QDateEdit *qslSentQDateEdit, *qslRecQDateEdit;
-    QTextEdit *qslmsgTextEdit;
-    QLineEdit *qslViaLineEdit;
+    //QComboBox *qslSentComboBox, *qslRecComboBox, *qslSentViaComboBox, *qslRecViaComboBox;
+    //QDateEdit *qslSentQDateEdit, *qslRecQDateEdit;
+    //QTextEdit *qslmsgTextEdit;
+    //QLineEdit *qslViaLineEdit;
 
 
-    QLineEdit *searchBoxLineEdit;
-    QPushButton *searchBoxClearButton, *searchBoxExportButton, *searchBoxSelectAllButton, *searchBoxReSearchButton;
-    QRadioButton *searchAllRadioButton;
+    //QLineEdit *searchBoxLineEdit;
+    //QPushButton *searchBoxClearButton, *searchBoxExportButton, *searchBoxSelectAllButton, *searchBoxReSearchButton;
+    //QRadioButton *searchAllRadioButton;
     QPushButton *recalculateAwardsButton;
-    bool searchSelectAllClicked, stationCallSignShownInSearch;
+    //bool searchSelectAllClicked, stationCallSignShownInSearch;
 
     bool checkNewVersions, reportInfo; // Selected in the Setup->Misc to check if new versions and report info back to KLog's servers
 
-
-
     bool qslingNeeded;
-
+    bool noMoreErrorShown;              // If true, the errors shown in slotQueryErrorManagement will not be shown anymore in that KLog execution
     MainWindowSatTab *satTabWidget;
     MainWindowMyDataTab *myDataTabWidget;
     MainWindowInputComment *commentTabWidget;
     MainWindowInputOthers *othersTabWidget;
+    MainWindowInputEQSL *eQSLTabWidget;
+    MainWindowInputQSL *QSLTabWidget;
+
+    SearchWidget *searchWidget;
+    InfoWidget *infoWidget;
+
     bool keepSatPage;
 
     // UI DX
@@ -533,8 +579,9 @@ private:
     QTimer *timer;
     QDateTime *dateTime;
 
-    QString kontestDir, ctyDatFile, defaultADIFLogFile, configFileName;
+    QString klogDir, ctyDatFile, defaultADIFLogFile, configFileName;
     QString softwareVersion;
+    bool itIsANewversion;
 
 
     QString currentQrz;
@@ -581,8 +628,8 @@ private:
     //</CLUBLOG>
 
     // Contest
-    int contestMode, points, qsoPoints, multipliers, qsoMultiplier;
-
+    int points, qsoPoints, multipliers, qsoMultiplier;
+    QString contestMode;
     Contest *contest;
     // Contest
     DataProxy *dataProxy;
@@ -595,6 +642,14 @@ private:
     SoftwareUpdate *softUpdate;
     bool callingUpdate;
 
+    //LOGVIEW
+    //QString bandOld, modeOld;
+    //LOGVIEW
+
+signals:
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+
+
 protected:
     void keyPressEvent(QKeyEvent *event);
     void closeEvent(QCloseEvent *event);
