@@ -27,14 +27,14 @@
 
 #include "mainwindowinputothers.h"
 
-MainWindowInputOthers::MainWindowInputOthers(QWidget *parent) :
+MainWindowInputOthers::MainWindowInputOthers(DataProxy *dp, QWidget *parent) :
     QWidget(parent)
 {
-   //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
+    //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
     entitiesList.clear();
     propModeList.clear();
 
-    dataProxy = new DataProxy_SQLite();
+    dataProxy = dp;
     propModeList = dataProxy->getPropModeList();
 
     //QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
@@ -51,6 +51,7 @@ MainWindowInputOthers::MainWindowInputOthers(QWidget *parent) :
 
 
     createUI();
+    //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << endl;
 }
 
 MainWindowInputOthers::~MainWindowInputOthers(){}
@@ -104,13 +105,13 @@ void MainWindowInputOthers::createUI()
 
     if (entitiesList.size()>1)
     {
-        entitiesList.prepend("00-Not Identified (000)");
+        entitiesList.prepend("00-" + tr("Not Identified") + " (000)");
         entityNameComboBox->addItems(entitiesList);
     }
 
     if (propModeList.size()>1)
     {
-        propModeList.prepend("00 - Not - Not Identified");
+        propModeList.prepend("00 - " + tr("Not - Not Identified"));
         propModeComboBox->addItems(propModeList);
     }
 /*
@@ -146,7 +147,8 @@ void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
     entitiesList << _qs;
     if (entitiesList.size()>1)
     {
-        entitiesList.prepend("00-Not Identified (000)");
+        entitiesList.prepend("00-" + tr("Not Identified") + " (000)");
+        //entitiesList.prepend("00-Not Identified (000)");
         entityNameComboBox->addItems(entitiesList);
     }
 }
@@ -237,7 +239,9 @@ bool MainWindowInputOthers::isIOTAModified()
 }
 
 void MainWindowInputOthers::setIOTA(const QString _qs, const bool _black)
-{
+{//TODO: Seems to be better to send the color info like in: (it is much more flexible as I can send any color!)
+
+    //void MainWindowInputQSL::setQSLVia(const QString _qs, QColor qColor)
    //qDebug() << "MainWindow::setIOTA: " << _qs << endl;
     if ( (checkIfValidIOTA(_qs)).length() !=6 )
     {
@@ -304,7 +308,7 @@ Returns a valid format IOTA if possible and "" in other cases.
 
 ************************************/
    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << endl;
-    bool _valid = false;
+    //bool _valid = false;
     QString _continent;
     QString _number;
 
