@@ -29,6 +29,7 @@
 MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
     QWidget(parent)
 {
+    //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab"   << endl;
     myPowerSpinBox = new QDoubleSpinBox;
     operatorLineEdit = new QLineEdit;
     stationCallSignLineEdit = new QLineEdit;
@@ -47,7 +48,7 @@ MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
 
     myPower = 0;
     lastPower = 0;
-
+    //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab - END"   << endl;
 
 }
 
@@ -57,7 +58,7 @@ void MainWindowMyDataTab::createUI()
 {
     myPowerSpinBox->setDecimals(2);
     myPowerSpinBox->setMaximum(9999);
-    myPowerSpinBox->setSuffix(tr("Watt"));
+    myPowerSpinBox->setSuffix(" " + tr("Watt"));
 
     QLabel *keepLabel = new QLabel();
     keepLabel->setText(tr("Keep this data"));
