@@ -7,20 +7,20 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 
@@ -32,16 +32,17 @@ This class calls all the othet "Setup..." to manage the configuration
 
 */
 
-SetupDialog::SetupDialog(const bool _firstTime)
+SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
 {
-  //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 1" << endl;
     util = new Utilities;
+    constrid = 1;
     nolog = true;
     configFileName = "klogrc";
     version = ".";
     pageRequested = 0;
   //qDebug() << "SetupDialog::SetupDialog 2" << endl;
-    dataProxy = new DataProxy_SQLite();
+    dataProxy = dp;
    //qDebug() << "SetupDialog::SetupDialog 3" << endl;
 
     firstTime = _firstTime;
@@ -63,9 +64,9 @@ SetupDialog::SetupDialog(const bool _firstTime)
    //qDebug() << "SetupDialog::SetupDialog 3.4" << endl;
 
 
-    userDataPage = new SetupPageUserDataPage();
+    userDataPage = new SetupPageUserDataPage(dataProxy);
    //qDebug() << "SetupDialog::SetupDialog 3.5" << endl;
-    bandsModesPage = new SetupPageBandsModes(this);
+    bandModePage = new SetupPageBandMode(dataProxy, this);
    //qDebug() << "SetupDialog::SetupDialog 3.6" << endl;
     dxClusterPage = new SetupPageDxCluster(this);
    //qDebug() << "SetupDialog::SetupDialog 3.7" << endl;
@@ -73,9 +74,9 @@ SetupDialog::SetupDialog(const bool _firstTime)
    //qDebug() << "SetupDialog::SetupDialog 3.8" << endl;
     miscPage = new SetupPageMisc(this);
    //qDebug() << "SetupDialog::SetupDialog 3.9" << endl;
-    worldEditorPage = new SetupPageWorldEditor (this);
+    worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
    //qDebug() << "SetupDialog::SetupDialog 3.10" << endl;
-    logsPage = new SetupPageLogs(this);
+    logsPage = new SetupPageLogs(dataProxy, this);
    //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
     clubLogPage = new SetupPageClubLog(this);
    //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
@@ -83,7 +84,7 @@ SetupDialog::SetupDialog(const bool _firstTime)
    //qDebug() << "SetupDialog::SetupDialog 4" << endl;
 
     tabWidget->addTab(userDataPage, tr("My Data"));    
-    tabWidget->addTab(bandsModesPage, tr("Bands/Modes"));
+    tabWidget->addTab(bandModePage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("DX-Cluster"));
     tabWidget->addTab(colorsPage, tr("Colors"));
     tabWidget->addTab(miscPage, tr("Misc"));
@@ -95,7 +96,9 @@ SetupDialog::SetupDialog(const bool _firstTime)
     QPushButton *okButton = new QPushButton(tr("OK"));
 
     connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
+
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));       
+    connect(logsPage, SIGNAL(queryError(QString, QString, int, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, int, QString)) );    
     connectActions();
 
 
@@ -126,12 +129,13 @@ SetupDialog::SetupDialog(const bool _firstTime)
 }
 
 
-SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
+SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-  //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+    constrid = 2;
     util = new Utilities;
     firstTime = _firstTime;
-    dataProxy = new DataProxy_SQLite();
+    dataProxy = dp;
     configFileName = _configFile;
     version = _softwareVersion;
     pageRequested = _page;
@@ -142,17 +146,17 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
 
     tabWidget = new QTabWidget;
 
-    userDataPage = new SetupPageUserDataPage();
-    bandsModesPage = new SetupPageBandsModes(this);
+    userDataPage = new SetupPageUserDataPage(dataProxy);
+    bandModePage = new SetupPageBandMode(dataProxy, this);
     dxClusterPage = new SetupPageDxCluster(this);
     colorsPage = new SetupPageColors(this);
     miscPage = new SetupPageMisc(this);
-    worldEditorPage = new SetupPageWorldEditor (this);
-    logsPage = new SetupPageLogs(this);
+    worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
+    logsPage = new SetupPageLogs(dataProxy, this);
     clubLogPage = new SetupPageClubLog(this);
     //qDebug() << "SetupDialog::SetupDialog 02" << endl;
     tabWidget->addTab(userDataPage, tr("User data"));
-    tabWidget->addTab(bandsModesPage, tr("Bands/Modes"));
+    tabWidget->addTab(bandModePage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("D&X-Cluster"));
     tabWidget->addTab(colorsPage, tr("Colors"));
     tabWidget->addTab(miscPage, tr("Misc"));
@@ -197,10 +201,12 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
     }
    //qDebug() << "SetupDialog::SetupDialog 05.3" << endl;
     nolog = !(haveAtleastOneLog());
-   //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
+
     connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
     connectActions();
+
+    //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
 }
 
 
@@ -215,6 +221,7 @@ void SetupDialog::connectActions()
     connect (logsPage, SIGNAL(newLogData(QStringList)), this, SLOT(slotAnalyzeNewLogData(QStringList)));
     connect (userDataPage, SIGNAL(stationCallSignal(QString)), this, SLOT(slotSetStationCallSign(QString)));
     connect (userDataPage, SIGNAL(operatorsSignal(QString)), this, SLOT(slotSetOperators(QString)));
+    connect (userDataPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
 
 }
 
@@ -230,6 +237,8 @@ void SetupDialog::setData(const QString _configFile, const QString _softwareVers
     else
     {
        //qDebug() << "SetupDialog::setData NOT FIRST TIME! " << endl;
+
+        miscPage->setUseDefaultDBPath(miscPage->getDefaultDBPath());
     }
 
     setConfigFile(_configFile);
@@ -273,7 +282,7 @@ void SetupDialog::slotCancelButtonClicked()
         {
             QMessageBox msgBox;
             msgBox.setIcon(QMessageBox::Information);
-            msgBox.setText(tr("You need to enter at least one log in the Log's tab."));
+            msgBox.setText(tr("You need to enter at least one log in the Logs tab."));
             msgBox.exec();
             return;
         }
@@ -348,7 +357,17 @@ void SetupDialog::changePage(QListWidgetItem *current, QListWidgetItem *previous
 
 void SetupDialog::slotOkButtonClicked()
 {
-//qDebug() << "SetupDialog::slotOkButonClicked" << endl;
+qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
+
+    if (!miscPage->areDBPathChangesApplied())
+    {
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Warning);
+        msgBox.setText(tr("DB has not been moved to new path"));
+        msgBox.setInformativeText(tr("Go to the") + " " + tr("Misc tab") + " " + tr("and click on") + " " + tr("Move DB") + "\n" + tr("or the DB will not be moved to the new location."));
+        msgBox.exec();
+        return;
+    }
 
     if ((userDataPage->getStationQrz()).length() < 3){ // There are no valid calls with less than 3 Chars
         QMessageBox msgBox;
@@ -361,7 +380,7 @@ void SetupDialog::slotOkButtonClicked()
 
     if (!haveAtleastOneLog())
     {
-       //qDebug() << "SetupDialog::slotOkButonClicked - NO LOG!" << endl;
+       //qDebug() << "SetupDialog::slotOkButtonClicked - NO LOG!" << endl;
 
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
@@ -473,8 +492,8 @@ void SetupDialog::slotOkButtonClicked()
         //stream << "locator=" << (MyLocatorkLineEdit->text ()).toUpper () <<  ";" << endl;
         //stream << "CallUsed=" << (UserDataPage.qrzLineEdit).text() <<  ";" << endl;
         //stream << "Operators=" <<  ";" << endl;
-        stream << "Bands=" << bandsModesPage->getBands() << ";" <<  endl;
-        stream << "Modes=" << bandsModesPage->getModes() << ";" <<  endl;
+        stream << "Bands=" << bandModePage->getBands() << ";" <<  endl;
+        stream << "Modes=" << bandModePage->getModes() << ";" <<  endl;
 
         //stream << "InMemory=" << miscPage->getInMemory() << ";" <<  endl;
         stream << "RealTime=" << miscPage->getRealTime() << ";" <<  endl;
@@ -482,6 +501,7 @@ void SetupDialog::slotOkButtonClicked()
         stream << "AlwaysADIF=" << miscPage->getAlwaysADIF() << ";" <<  endl;
         stream << "UseDefaultName=" << miscPage->getUseDefaultName() << ";" <<  endl;
         stream << "DefaultADIFFile=" << miscPage->getDefaultFileName() << ";" <<  endl;
+        stream << "DBPath=" << miscPage->getDefaultDBPath() << ";" <<  endl;
         stream << "ImperialSystem=" << miscPage->getImperial() << ";" <<  endl;
         stream << "SendQSLWhenRec=" << miscPage->getSendQSLWhenRec() << ";" <<  endl;
         stream << "ShowCallsignInSearch=" << miscPage->getShowStationCallSignInSearch() << ";" <<  endl;
@@ -544,28 +564,29 @@ void SetupDialog::slotOkButtonClicked()
 
         file.close ();
     }
-
+    //qDebug() << "SetupDialog::slotOkButtonClicked - just before leaving" << endl;
     QDialog::accept();
+    //qDebug() << "SetupDialog::slotOkButtonClicked - END" << endl;
     //close();
 }
 
 void SetupDialog::slotReadConfigData()
 {
- //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData" << endl;
     if (firstTime)
     {
         setDefaults();
         bands.removeDuplicates();
         modes.removeDuplicates();
-        bandsModesPage->setActiveModes(modes);
-        bandsModesPage->setActiveBands(bands);
+        bandModePage->setActiveModes(modes);
+        bandModePage->setActiveBands(bands);
     }
 
-    //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
+        //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
 
     QFile file(configFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-      //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
+        //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
         //firstTime = true;
         return;
     }
@@ -596,10 +617,10 @@ void SetupDialog::slotReadConfigData()
     }
     modes.removeDuplicates();
     //qDebug() << "SetupDialog::slotReadConfigData - duplicate modes: " << QString::number(a)  << endl;
-    bandsModesPage->setActiveModes(modes);
+    bandModePage->setActiveModes(modes);
     bands.removeDuplicates();
   //qDebug() << "SetupDialog::slotReadConfigData - duplicate bands: " << QString::number(a)  << endl;
-    bandsModesPage->setActiveBands(bands);
+    bandModePage->setActiveBands(bands);
    //qDebug() << "SetupDialog::slotReadConfigData - END" << endl;
 
 }
@@ -647,13 +668,15 @@ bool SetupDialog::processConfigLine(const QString _line)
     }else if (tab=="CONTEST"){
         //userDataPage->setContest(value);
     }else if (tab=="MODES"){
+        //qDebug() << "SetupDialog::processConfigLine: MODES: " << value << endl;
         readActiveModes(value);
         modes.removeDuplicates();
-        bandsModesPage->setActiveModes(modes);
+        bandModePage->setActiveModes(modes);
+        //qDebug() << "SetupDialog::processConfigLine: MODES-2: " << value << endl;
     }else if (tab=="BANDS"){
         readActiveBands(value);
         bands.removeDuplicates();
-        bandsModesPage->setActiveBands(bands);
+        bandModePage->setActiveBands(bands);
     //}else if (tab=="INMEMORY"){
     //    miscPage->setInMemory(value);
     }else if (tab=="REALTIME"){
@@ -664,6 +687,8 @@ bool SetupDialog::processConfigLine(const QString _line)
         miscPage->setAlwaysADIF(value);
     }else if (tab=="USEDEFAULTNAME"){
         miscPage->setDefaultFileName(value);
+    }else if (tab=="DBPATH"){
+        miscPage->setUseDefaultDBPath(value);
     }else if (tab=="DEFAULTADIFFILE"){
         miscPage->setDefaultFileName(value.toLower());
         //qDebug() << "SetupDialog::processConfigLine: FILE: " << value << endl;
@@ -790,20 +815,25 @@ bool SetupDialog::processConfigLine(const QString _line)
         colorsPage->setConfirmedColor(value);
     }else if(tab =="DEFAULTCOLOR"){
         colorsPage->setDefaultColor(value);
-    }else if(tab =="SELECTEDLOG"){        
+    }else if(tab =="SELECTEDLOG"){
+        //qDebug() << "SetupDialog::processConfigLine: SELECTEDLOG: " << value << endl;
         i = value.toInt();
+
         if (dataProxy->doesThisLogExist(i))
         {
+            //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist TRUE" << endl;
         }
         else
         {
-            i = 1;
+            //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist FALSE" << endl;
+            i = 0;
             while(!dataProxy->doesThisLogExist(i))
             {
                 i++;
             }
         }
         logsPage->setSelectedLog(i);
+        //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist END" << endl;
 
     }else if(tab =="CLUBLOGACTIVE"){
         clubLogPage->setClubLog(value);
@@ -890,10 +920,8 @@ void SetupDialog::readActiveModes (const QString actives)
                 atLeastOne = true;
                 _amodes.clear();
             }
-
             _amodes << values.at(i);
         }
-
     }
 
     modes.clear();
@@ -901,10 +929,7 @@ void SetupDialog::readActiveModes (const QString actives)
     modes << _amodes;
     modes.removeDuplicates();
 
-
-    //qDebug() << "SetupDialog::readActiveModes: " << modes.join(" / ") << endl;
-
-
+    //qDebug() << "SetupDialog::readActiveModes-end: " << modes.join(" / ") << endl;
 }
 
 bool SetupDialog::isValidBand (const QString b)
@@ -1019,18 +1044,18 @@ void SetupDialog::checkIfNewBandOrMode()
     //qDebug() << "SetupDialog::checkIfNewBandOrMode -1" << endl;
     _items << dataProxy->getBandsInLog(-1);
     //qDebug() << "SetupDialog::checkIfNewBandOrMode -2" << endl;
-    _items << (bandsModesPage->getBands()).split(", ", QString::SkipEmptyParts);
+    _items << (bandModePage->getBands()).split(", ", QString::SkipEmptyParts);
     //qDebug() << "SetupDialog::checkIfNewBandOrMode -3" << endl;
     _items.removeDuplicates();
     //qDebug() << "SetupDialog::checkIfNewBandOrMode -4" << endl;
-    bandsModesPage->setActiveBands(_items);
+    bandModePage->setActiveBands(_items);
     //qDebug() << "SetupDialog::checkIfNewBandOrMode -5" << endl;
 
     _items.clear();
     _items << dataProxy->getModesInLog(-1);
-    _items << (bandsModesPage->getModes()).split(", ", QString::SkipEmptyParts);
+    _items << (bandModePage->getModes()).split(", ", QString::SkipEmptyParts);
     _items.removeDuplicates();
-    bandsModesPage->setActiveModes(_items);
+    bandModePage->setActiveModes(_items);
     //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << endl;
 
 }
@@ -1047,6 +1072,7 @@ void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
     }
     userDataPage->setStationQrz(_qs.at(0));
     userDataPage->setOperators(_qs.at(1));
+
 }
 
 void SetupDialog::slotSetStationCallSign(const QString _p)
@@ -1061,3 +1087,7 @@ void SetupDialog::slotSetOperators(const QString _p)
     logsPage->setDefaultOperators(_p);
 }
 
+void SetupDialog::slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery)
+{
+    emit queryError(functionFailed, errorCodeS, errorCodeN, failedQuery);
+}
