@@ -30,15 +30,13 @@
 #include <QDialog>
 
 #include "setuppageuserdata.h"
-#include "setuppagebandsmodes.h"
+#include "setuppagebandmode.h"
 #include "setuppagemisc.h"
 #include "setuppagedxcluster.h"
 #include "setuppagecolors.h"
 #include "setuppagelogs.h"
 #include "setuppageworldeditor.h"
 #include "setuppageclublog.h"
-
-#include "dataproxy_sqlite.h"
 #include "utilities.h"
 
 
@@ -54,8 +52,8 @@ class SetupDialog : public QDialog
     Q_OBJECT
 
 public:
-    SetupDialog(const bool _firstTime=true);
-    SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page=0, const bool _firstTime = true);    
+    SetupDialog(DataProxy *dp, const bool _firstTime=true);
+    SetupDialog(DataProxy *dp, const QString _configFile, const QString _softwareVersion, const int _page=0, const bool _firstTime = true);
     ~SetupDialog();
 
     void setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime=true);
@@ -66,6 +64,7 @@ public slots:
 
 signals:
     void exitSignal(const int status); // 1 = OK, -1 = NOK, 2 = Cancel clicked
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
     //void newLogRequested(const bool _s); // true show new log
 
 private slots:
@@ -76,6 +75,7 @@ private slots:
     void slotAnalyzeNewLogData(const QStringList _qs);  // We receive the station callsign and operators from the logs tab
     void slotSetStationCallSign(const QString _p);      // We receive te station callsign from the userData tab to fill the new log
     void slotSetOperators(const QString _p);            // We receive te station operators from the userData tab to fill the new log
+    void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
 
 private:
 
@@ -110,7 +110,7 @@ private:
     QStackedWidget *pagesWidget;
 
     SetupPageUserDataPage *userDataPage;
-    SetupPageBandsModes *bandsModesPage;
+    SetupPageBandMode *bandModePage;
     SetupPageDxCluster *dxClusterPage;
     SetupPageMisc *miscPage;
     SetupPageColors *colorsPage;
@@ -119,7 +119,7 @@ private:
     SetupPageClubLog *clubLogPage;
 
     int pageRequested; // The page on the Dialog that is requested to be shown when you call it
-    //QString kontestDir;
+    //QString klogDir;
     QString configFileName, version;
 
     QStringList bands, modes;
@@ -127,6 +127,8 @@ private:
     DataProxy *dataProxy;
 
     Utilities *util;
+
+    int constrid; // Just an id for the constructor to check who is being executed at one specific time
 };
 
 
