@@ -28,12 +28,13 @@
 
 #include "setuppagelogs.h"
 
-SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
-//qDebug() << "SetupPageLogs::SetupPageLogs" << endl;
-
+SetupPageLogs::SetupPageLogs(DataProxy *dp, QWidget *parent) : QWidget(parent){
+    //qDebug() << "SetupPageLogs::SetupPageLogs" << endl;
+    dataProxy = dp;
     stationCallsign = QString();
     operators = QString();
     comment = QString();
+    //dateString = QDate::currentDate().toString("yyyy/MM/dd");
     dateString = QString();
     typeContest = QString();
     contestCatMode = -1;
@@ -52,7 +53,7 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
     currentLogs = new QComboBox();
     logsAvailable.clear();
 
-    newLog = new SetupPageLogsNew();
+    newLog = new SetupPageLogsNew(dataProxy);
     logsModel = new QSqlRelationalTableModel(this);
     logsView = new QTableView;
     logsView->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -94,7 +95,7 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
 
     setLayout(widgetLayout);
 
-    dataProxy = new DataProxy_SQLite();
+
 
     //connect(newLogPushButton, SIGNAL(clicked ( )), this, SLOT(slotNewButtonClicked() ) );
     //QObject::connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
@@ -105,7 +106,7 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
     updateSelectedLogs();
 
 
-
+    //qDebug() << "SetupPageLogs::SetupPageLogs - END" << endl;
 }
 
 SetupPageLogs::~SetupPageLogs(){
@@ -127,6 +128,8 @@ void SetupPageLogs::createNewLog()
     {
         newLog->setOperators(defaultOperators);
     }
+    newLog->setDateString(QDate::currentDate().toString("yyyy/MM/dd"));
+    newLog->setComment("");
 
     newLog->exec();
 }
@@ -141,10 +144,22 @@ void SetupPageLogs::slotNewButtonClicked()
 void SetupPageLogs::slotEditButtonClicked()
 {
     //qDebug() << "SetupPageLogs::slotEditButtonClicked" << endl;
-    QSqlQuery query;
-    int nameCol = -1;
+    //QSqlQuery query;
+    //int nameCol = -1;
 
     selectedLog = getSelectedLog();
+
+    QString getStationCallSignFromLog(const int _log);
+
+    newLog->setEditing(true);
+
+    newLog->setStationCallSign(dataProxy->getStationCallSignFromLog(selectedLog));
+    newLog->setOperators(dataProxy->getOperatorsFromLog(selectedLog));
+    newLog->setComment(dataProxy->getCommentsFromLog(selectedLog));
+    newLog->setDateString(dataProxy->getLogDateFromLog(selectedLog));
+    newLog->setTypeN(dataProxy->getLogTypeNFromLog(selectedLog).toInt());
+
+/*
     //qDebug() << "SetupPageLogs::slotEditButtonClicked-1 (selectedlog: " << QString::number(selectedLog) << ")" << endl;
     QString stringQuery = QString("SELECT * FROM logs WHERE id='%1'").arg(selectedLog);
     //qDebug() << "SetupPageLogs::slotEditButtonClicked -2" << endl;
@@ -159,28 +174,35 @@ void SetupPageLogs::slotEditButtonClicked()
         {//id/logdate/stationcall/comment/logtype/logtypeid
             //qDebug() << "SetupPageLogs::slotEditButtonClicked Query Valid" << endl;
 
-            newLog->setEditing(true);
 
-            nameCol = rec.indexOf("stationcall");
-            newLog->setStationCallSign((query.value(nameCol)).toString());
 
-            nameCol = rec.indexOf("operators");
-            newLog->setOperators((query.value(nameCol)).toString());
+            //nameCol = rec.indexOf("stationcall");
+            //newLog->setStationCallSign((query.value(nameCol)).toString());
+            //nameCol = rec.indexOf("operators");
+            //newLog->setOperators((query.value(nameCol)).toString());
 
-            nameCol = rec.indexOf("comment");
-            newLog->setComment((query.value(nameCol)).toString());
 
-            nameCol = rec.indexOf("logdate");
-            newLog->setDateString((query.value(nameCol)).toString());
 
-            nameCol = rec.indexOf("logtypen");
+
+            //nameCol = rec.indexOf("comment");
+            //newLog->setComment((query.value(nameCol)).toString());
+
+            //nameCol = rec.indexOf("logdate");
+            //newLog->setDateString((query.value(nameCol)).toString());
+
+            //nameCol = rec.indexOf("logtypen");
             //qDebug() << "SetupPageLogs::slotEditButtonClicked -3" << endl;
-            newLog->setTypeN((query.value(nameCol)).toInt());
+            //newLog->setTypeN((query.value(nameCol)).toInt());
 
             newLog->exec();
         }
 
     }
+    else
+    {
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
+    }
+    */
 }
 
 void SetupPageLogs::slotLogsCancelled(const bool _q)
@@ -195,8 +217,8 @@ void SetupPageLogs::slotRemoveButtonClicked()
 
     QMessageBox::StandardButton ret;
     ret = QMessageBox::warning(this, tr("KLog"),
-             tr("Do you really want to remove this log?\n"
-                "All the QSO from this log will be also deleted..."),
+             tr("Do you really want to remove this log?") + "\n" +
+                tr("All the QSOs from this log will be also deleted..."),
              QMessageBox::Yes | QMessageBox::No);
     if (ret == QMessageBox::Yes)
     {
@@ -224,15 +246,14 @@ void SetupPageLogs::slotRemoveButtonClicked()
                 if (sqlOk)
                 {
                     //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC REMOVED: " << QString::number(selectedLog) << ")" << endl;
-
                 }
                 else
                 {
+                    emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
                     showError(tr("Log has not been removed. (#3)"));
                     //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
                 }
 
-
             }
             else
             {
@@ -242,14 +263,12 @@ void SetupPageLogs::slotRemoveButtonClicked()
         }
         else
         {
+            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
             showError(tr("Log has not been removed. (#1)"));
             //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
         }
-
     }
 
-
-
     //ASK FOR A CONFIRMATION
 
     //DELETE ALL THE QSO IN THE REMOVED LOG
@@ -275,6 +294,8 @@ void SetupPageLogs::createLogsPanel()
     logsView->setColumnHidden(columns, false);
     columns = rec.indexOf("stationcall");
     logsView->setColumnHidden(columns, false);
+    columns = rec.indexOf("operators");
+    logsView->setColumnHidden(columns, false);
     columns = rec.indexOf("comment");
     logsView->setColumnHidden(columns, false);
     columns = rec.indexOf("logtype");
@@ -311,6 +332,9 @@ void SetupPageLogs::createLogsModel()
         nameCol = rec.indexOf("stationcall");
         logsModel->setHeaderData(nameCol, Qt::Horizontal, tr("Station Callsign"));
 
+        nameCol = rec.indexOf("operators");
+        logsModel->setHeaderData(nameCol, Qt::Horizontal, tr("Operators"));
+
         nameCol = rec.indexOf("comment");
         logsModel->setHeaderData(nameCol, Qt::Horizontal, tr("Comments"));
 
@@ -384,10 +408,6 @@ QStringList SetupPageLogs::readLogs()
             nameCol = rec.indexOf("id");
             aux2 = (query.value(nameCol)).toString();
 
-            nameCol = rec.indexOf("logdate");
-            aux2 = aux2.append("--");
-            aux2.append((query.value(nameCol)).toString());
-
             nameCol = rec.indexOf("stationcall");
             aux2 = aux2.append("-");
             aux2.append((query.value(nameCol)).toString());
@@ -396,6 +416,11 @@ QStringList SetupPageLogs::readLogs()
             aux2 = aux2.append("-");
             aux2.append((query.value(nameCol)).toString());
 
+            nameCol = rec.indexOf("logdate");
+            aux2 = aux2.append(" (");
+            aux2.append((query.value(nameCol)).toString());
+            aux2 = aux2.append(")");
+
             _logs.append(aux2);
 
         }
@@ -403,6 +428,7 @@ QStringList SetupPageLogs::readLogs()
     }
     else
     {
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
         return _logs;
     }
 
@@ -419,11 +445,12 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
 {
     //qDebug() << "SetupPageLogs::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
 
+
     if (_qs.length()!=14)
     {
         return;
     }
-/* From SetupPageLogsNew::gatherAndSend()
+/*     From SetupPageLogsNew::gatherAndSend()
     logData.clear();
     logData << stationCallsign << operators << comment << dateString
             << typeConteststr
@@ -444,6 +471,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     comment = _qs.at(2);
     dateString = _qs.at(3);
     typeContest  = _qs.at(4);
+/*
     contestCatMode  = (_qs.at(5)).toInt();
     contestCatOperators  = (_qs.at(6)).toInt();
     contestCatAssisted  = (_qs.at(7)).toInt();
@@ -451,6 +479,8 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     contestCatBands  = (_qs.at(9)).toInt();
     contestBands  = (_qs.at(10)).toInt();
     typeContestN = (_qs.at(12)).toInt();
+*/
+/*
     bool editing;
     if ( (_qs.at(13)).toInt() == 1)
     {
@@ -460,13 +490,26 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     {
         editing = false;
     }
+*/
     //OVERLAY = 11
+/*
+    QString _dateString = _qs.at(0);
+    QString _stationCallsign = _qs.at(1);
+    QString _operators = _qs.at(2);
 
+    QString _typeContest = _qs.at(3);
+    QString _comment = _qs.at(4);
+    QString _typeContestN = _qs.at(5);
+    QString id = _qs.at(6);
+    QString editing = _qs.at(7);
+*/
 
     QStringList newLogq;
     newLogq.clear();
     //If qs.at(12) == 1 then we are editing, any other value is a new log
-    newLogq << dateString << stationCallsign << operators << _qs.at(4) << comment << _qs.at(12) << QString::number(selectedLog) << _qs.at(13) ;
+    //Date/Call/Operators/"DX"/comment/"1"
+    newLogq << dateString << stationCallsign << operators << typeContest << comment << "1" << QString::number(selectedLog) << _qs.at(13) ;
+
     if (dataProxy->addNewLog(newLogq))
     {
         logsModel->select();
@@ -476,7 +519,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     // We send the data to the main tab
     QStringList logData;
     logData.clear();
-    logData << stationCallsign << operators;
+    logData << stationCallsign << operators  ;
     emit newLogData(logData);
 }
 /*
@@ -603,8 +646,10 @@ contestBands  = (_qs.at(10)).toInt();
 
 void SetupPageLogs::showError(const QString _errorC)
 {
-    QString text = QString(tr("An error has ocurred showing the following error code:\n'%1'")).arg(_errorC);
-    int ret = QMessageBox::warning(this, tr("KLog - SetupPageLogs"),
+    QString text = QString(tr("An error has occurred showing the following error code:") + "\n'%1'").arg(_errorC);
+
+
+    QMessageBox::warning(this, tr("KLog - SetupPageLogs"),
                                    text,
                                    QMessageBox::Ok);
 
