@@ -30,9 +30,10 @@
 #include "setuppagelogsnew.h"
 
 
-SetupPageLogsNew::SetupPageLogsNew(QWidget *parent)
+SetupPageLogsNew::SetupPageLogsNew(DataProxy *dp, QWidget *parent)
 {
-    dataProxy = new DataProxy_SQLite();
+    //qDebug() << "SetupPageLogsNew::SetupPageLogsNew"   << endl;
+    dataProxy = dp;
     editing = false;
     checking = false;
     bCass = false;
@@ -97,9 +98,10 @@ SetupPageLogsNew::SetupPageLogsNew(QWidget *parent)
     cancelButton = new QPushButton(tr("&Cancel"), this);
     createWidget();
 
-    isThereAnyNotManagedLog();
+
     okButton->setEnabled(false);
 
+    //qDebug() << "SetupPageLogsNew::SetupPageLogsNew - END"   << endl;
 }
 
 void SetupPageLogsNew::clear()
@@ -250,11 +252,14 @@ void SetupPageLogsNew::createWidget()
     callsLayout->addWidget(stationCallsignLineEdit, 0, 1);
     callsLayout->addWidget(dateLabel, 1, 0);
     callsLayout->addWidget(dateEdit, 1, 1);
-
     callsLayout->addWidget(operatorsLabel, 2, 0);
     callsLayout->addWidget(operatorsLineEdit, 2, 1);
+    callsLayout->addWidget(commentLabel, 3, 0);
+    callsLayout->addWidget(commentLineEdit, 3, 1);
+/*
     callsLayout->addWidget(typeLabel, 3, 0);
     callsLayout->addWidget(typeComboBox, 3, 1);
+
     callsLayout->addWidget(catModeLabel, 4, 0);
     callsLayout->addWidget(contestCatModeComboBox, 4, 1);
     callsLayout->addWidget(catOpLabel, 5, 0);
@@ -268,14 +273,14 @@ void SetupPageLogsNew::createWidget()
     callsLayout->addWidget(catBandsLabel, 8, 0);
     callsLayout->addWidget(contestCatBandsComboBox, 8, 1);
     callsLayout->addWidget(contestBandsComboBox, 8, 2);
-    callsLayout->addWidget(commentLabel, 9, 0);
-    callsLayout->addWidget(commentLineEdit, 9, 1);
+
 
     callsLayout->addWidget(overlayLabel, 10, 0);
     callsLayout->addWidget(contestCatOverlayComboBox, 10, 1);
+*/
 
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
-    buttonsLayout->addWidget(validCats);
+    //buttonsLayout->addWidget(validCats);
     buttonsLayout->addSpacerItem(new QSpacerItem(10,0,QSizePolicy::Expanding,QSizePolicy::Maximum));
     buttonsLayout->addWidget(okButton);
     buttonsLayout->addWidget(cancelButton);
@@ -696,6 +701,19 @@ void SetupPageLogsNew::slotOKButtonClicked()
 void SetupPageLogsNew::gatherAndSend()
 {
      //qDebug() << "SetupPageLogsNew::gatherAndSend: " << typeConteststr << endl;
+
+    // The following lines will be removed once more contest types have been added
+    contestCatMode = contestCatModeComboBox->currentIndex();
+    contestCatBands = contestCatBandsComboBox->currentIndex();
+    contestCatPower = contestCatPowerComboBox->currentIndex();
+    contestCatOperators = contestCatOperatorsComboBox->currentIndex();
+    contestCatAssisted = contestCatAssistedComboBox->currentIndex();
+    typeContestSelected = typeComboBox->currentIndex();
+    contestCatOverlay = contestCatOverlayComboBox->currentIndex();
+    typeContest = getSelectedTypeContest();
+
+    // The previous lines will be removed once more contest types have been added
+
     logData.clear();
 
     logData << stationCallsign << operators << comment << dateString
@@ -720,6 +738,12 @@ void SetupPageLogsNew::gatherAndSend()
     }
     //logData << QString::number(typeContest)
     // Update the SetupPageLogs::slotAnalyzeNewLogData if you add or remove any field (Today 12)
+
+    //for (int i=0;i<logData.length();i++)
+    //{
+    //qDebug() << "SetupPageLogsNew::gatherAndSend: " << logData.at(i) << endl;
+    //}
+    //qDebug() << "SetupPageLogsNew::gatherAndSend: EMITED" << endl;
     emit newLogData(logData);
 
 }
@@ -749,32 +773,6 @@ QStringList SetupPageLogsNew::getValidCatOptions(const int _currentCat, const in
     return QStringList();
 }
 
-bool SetupPageLogsNew::isThereAnyNotManagedLog()
-{
-    //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog" << endl;
-
-    QSqlQuery query;
-    if (query.exec("SELECT DISTINCT lognumber FROM log WHERE lognumber!=1"))
-    {
-        while (query.next())
-        {
-            //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog en el while" << endl;
-            if (query.isValid())
-            {
-                //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog - Log found!:  " << QString::number((query.value(0)).toInt()) << endl;
-
-            }
-            else
-            {
-                //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog Not valid!" << endl;
-            }
-            //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog en el while - FINAL" << endl;
-        }
-        //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog tras el while" << endl;
-    }
-    //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog END" << endl;
-    return false;
-}
 
 void SetupPageLogsNew::setStationCallSign(const QString _st)
 {
