@@ -26,9 +26,11 @@
 
 #include "setuppageuserdata.h"
 
-SetupPageUserDataPage::SetupPageUserDataPage(QWidget *parent) : QWidget(parent){
-
+SetupPageUserDataPage::SetupPageUserDataPage(DataProxy *dp, QWidget *parent) : QWidget(parent){
+   //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage" << endl;
    locator = new Locator();
+   dataProxy = dp;
+   world = new World(dataProxy);
    operatorOK = false;
    operatorsOK = false;
    tabWidget = new QTabWidget;
@@ -68,8 +70,8 @@ SetupPageUserDataPage::SetupPageUserDataPage(QWidget *parent) : QWidget(parent){
    nameLineEdit->setToolTip(tr("Enter your name"));
    address1LineEdit->setToolTip(tr("Enter your address - 1st line"));
    address2LineEdit->setToolTip(tr("Enter your address - 2nd line"));
-   address3LineEdit->setToolTip(tr("Enter your address - 3st line"));
-   address4LineEdit->setToolTip(tr("Enter your address - 4nd line"));
+   address3LineEdit->setToolTip(tr("Enter your address - 3rd line"));
+   address4LineEdit->setToolTip(tr("Enter your address - 4th line"));
    cityLineEdit->setToolTip(tr("Enter your city"));
    zipLineEdit->setToolTip(tr("Enter your zip code"));
    provinceLineEdit->setToolTip(tr("Enter your province or state"));
@@ -134,12 +136,12 @@ SetupPageUserDataPage::SetupPageUserDataPage(QWidget *parent) : QWidget(parent){
    myPowerSpinBox->setDecimals(2);
    myPowerSpinBox->setMaximum(9999);
 
-   rig1LineEdit->setToolTip(tr("Enter your rig #1 information"));
-   rig2LineEdit->setToolTip(tr("Enter your rig #2 information"));
-   rig3LineEdit->setToolTip(tr("Enter your rig #3 information"));
-   ant1LineEdit->setToolTip(tr("Enter your antenna #1 information"));
-   ant2LineEdit->setToolTip(tr("Enter your antenna #2 information"));
-   ant3LineEdit->setToolTip(tr("Enter your antenna #3 information"));
+   rig1LineEdit->setToolTip(tr("Enter your information for rig") + " #1");
+   rig2LineEdit->setToolTip(tr("Enter your information for rig") + " #2");
+   rig3LineEdit->setToolTip(tr("Enter your information for rig") + " #3");
+   ant1LineEdit->setToolTip(tr("Enter your information for antenna") + " #1");
+   ant2LineEdit->setToolTip(tr("Enter your information for antenna") + " #2");
+   ant3LineEdit->setToolTip(tr("Enter your information for antenna") + " #3");
    myPowerSpinBox->setToolTip(tr("Enter your power information"));
 
    QLabel *rig1Label = new QLabel(tr("&Rig 1"));
@@ -183,7 +185,7 @@ SetupPageUserDataPage::SetupPageUserDataPage(QWidget *parent) : QWidget(parent){
     //TODO:Defining ALL the tooltips
     qrzLineEdit->setToolTip(tr("Enter the station callsign that will be used for logging"));
     operatorsLineEdit->setToolTip(tr("Enter the operators (comma separated if more than one)."));
-    myLocatorLineEdit->setToolTip(tr("Enter the locator of your station. KLog will propose one locator based on your callsign"));
+    myLocatorLineEdit->setToolTip(tr("Enter the locator of your station. Alternatively, KLog can use an approximate locator based on your callsign."));
 
 
     QLabel *qrzLabel = new QLabel(tr("&QRZ"));
@@ -248,10 +250,28 @@ SetupPageUserDataPage::SetupPageUserDataPage(QWidget *parent) : QWidget(parent){
     //mainLayout->addStretch(1);
 
     connect(qrzLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotQRZTextChanged() ) );
+    connect(qrzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(operatorsLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(nameLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(cqzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(ituzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(myLocatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+
+    connect(address1LineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(address2LineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(address3LineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(address4LineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(cityLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(zipLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(provinceLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(countryLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+
     connect(myLocatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotMyLocatorTextChanged() ) );
     connect(operatorsLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotOperatorsChanged() ) );
 
     setLayout(mainLayout);
+
+    //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage - END" << endl;
 }
 
 
@@ -262,7 +282,7 @@ SetupPageUserDataPage::~SetupPageUserDataPage()
 
 QString SetupPageUserDataPage::getStationQrz()
 {
-    operatorOK = world.checkQRZValidFormat(qrzLineEdit->text());
+    operatorOK = world->checkQRZValidFormat(qrzLineEdit->text());
     if (operatorOK)
     {
         return qrzLineEdit->text();
@@ -275,6 +295,11 @@ QString SetupPageUserDataPage::getStationQrz()
 
 
 
+void SetupPageUserDataPage::slotEnterKeyPressed()
+{
+    emit enterKey();
+}
+
 void SetupPageUserDataPage::slotQRZTextChanged()
 {
    //qDebug() << "SetupPageUserDataPage::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << endl;
@@ -289,9 +314,9 @@ void SetupPageUserDataPage::slotQRZTextChanged()
     qrzLineEdit->setText(((qrzLineEdit->text())).simplified());
     qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
 
-    cqzLineEdit->setText(QString::number(world.getQRZCqz(qrzLineEdit->text())));
-    ituzLineEdit->setText(QString::number(world.getQRZItuz(qrzLineEdit->text())));
-    myLocatorLineEdit->setText(world.getQRZLocator(qrzLineEdit->text()));
+    cqzLineEdit->setText(QString::number(world->getQRZCqz(qrzLineEdit->text())));
+    ituzLineEdit->setText(QString::number(world->getQRZItuz(qrzLineEdit->text())));
+    myLocatorLineEdit->setText(world->getQRZLocator(qrzLineEdit->text()));
 
     qrzLineEdit->setCursorPosition(i);
 
@@ -301,7 +326,7 @@ void SetupPageUserDataPage::slotQRZTextChanged()
     /*
      if (!locator->isValidLocator(myLocatorLineEdit->text()) )
     {
-        myLocatorLineEdit->setText(world.getQRZLocator(qrzLineEdit->text()));
+        myLocatorLineEdit->setText(world->getQRZLocator(qrzLineEdit->text()));
     }
     */
 }
@@ -628,9 +653,9 @@ void SetupPageUserDataPage::slotOperatorsChanged()
     {
         //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-03 - " << QString::number(ii) << endl;
 
-        operatorsOK = world.checkQRZValidFormat(operators.at(ii));
+        operatorsOK = world->checkQRZValidFormat(operators.at(ii));
 
-        //ent = world.getQRZARRLId(operators.at(ii));
+        //ent = world->getQRZARRLId(operators.at(ii));
 
         if (operatorsOK)
         {
@@ -663,9 +688,9 @@ void SetupPageUserDataPage::slotOperatorsChanged()
     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-05" << endl;
 
  /*
-    cqzLineEdit->setText(QString::number(world.getQRZCqz(qrzLineEdit->text())));
-    ituzLineEdit->setText(QString::number(world.getQRZItuz(qrzLineEdit->text())));
-    myLocatorLineEdit->setText(world.getQRZLocator(qrzLineEdit->text()));
+    cqzLineEdit->setText(QString::number(world->getQRZCqz(qrzLineEdit->text())));
+    ituzLineEdit->setText(QString::number(world->getQRZItuz(qrzLineEdit->text())));
+    myLocatorLineEdit->setText(world->getQRZLocator(qrzLineEdit->text()));
 
 
   */
@@ -703,7 +728,7 @@ bool  SetupPageUserDataPage::checkOperatorsLineQString(const QString _auxLine)
     QStringList _aux = _auxLine.split(',');
     for (int ii = 0; ii < _aux.size(); ++ii)
     {
-        operatorsOK = world.checkQRZValidFormat(_aux.at(ii));
+        operatorsOK = world->checkQRZValidFormat(_aux.at(ii));
         if (!operatorsOK)
             return operatorsOK;
 
