@@ -3,7 +3,7 @@
 
 SoftwareUpdate::SoftwareUpdate(const QString _klogVersion) : QObject(0)
 {
-    //qDebug() << "SoftwareUpdate::SoftwareUpdate(): " << _klogDir << endl;
+    //qDebug() << "SoftwareUpdate::SoftwareUpdate(): " << _klogVersion << endl;
     util = new Utilities;
     updateDialog = new SoftwareUpdateDialog();
     latestVersion = "0.0";
@@ -27,6 +27,7 @@ SoftwareUpdate::SoftwareUpdate(const QString _klogVersion) : QObject(0)
     //request.setUrl(QUrl("http://download.klog.xyz"));
     messageShown = false;
     setHeader();
+    //qDebug() << "SoftwareUpdate::SoftwareUpdate(): - END"  << endl;
 
 }
 
@@ -169,7 +170,9 @@ bool SoftwareUpdate::checkUpdates(QIODevice *data)
                    {
                      //qDebug() << "SoftwareUpdate::checkUpdates: MATCH: " << str << endl;
                        release = str.section("-",1);                       
-                       release = release.section("\.tar.gz", 0, 0);                       
+                       release = release.section(".tar.gz", 0, 0);
+                       //release = release.section("^.*([.]tar[.]gz)", 0, 0);
+                       //release = release.section("^.*\\.(tar.gz)?", 0, 0);
                        updateNeeded(release);
                    }
                    else
@@ -253,6 +256,8 @@ void SoftwareUpdate::connectToURL()
 void SoftwareUpdate::setHeader()
 {
     QString ver = util->getAgent(klogVersion);
+
+
     if (callsign.length()>2)
     {
         ver = ver + "-" + callsign;
@@ -261,6 +266,7 @@ void SoftwareUpdate::setHeader()
     str.clear();
     str.append(ver);
 
+    //qDebug() << "SoftwareUpdate::setHeader: " << str << endl;
     request.setRawHeader("User-Agent", str);
 }
 
