@@ -35,27 +35,29 @@ To insert a (key, value) pair into the hash, you can use operator[]():
  hash["EA8"] = 132;
 
 */
-World::World()
+World::World(DataProxy *dp)
 {
-  //qDebug() << "World::World(0)" << endl;
+    //qDebug() << "World::World(0)" << endl;
+    constrid = 1;
 
     worldModel = new QSqlRelationalTableModel(this);
     numberOfEntities = 0;
     progressBarPosition = 0;
-    kontestDir = "";
+    klogDir = "";
     kontestVersion = "";
     locator = new Locator();
     created = false;
-    dataProxy = new DataProxy_SQLite();
+    dataProxy = dp;
     //awards = new Awards();
-
+    //qDebug() << "World::World(0) - END" << endl;
 }
 
 
-World::World(const QString _kontestDir)
+World::World(DataProxy *dp, const QString _klogDir)
 {
-  //qDebug() << "World::World(1): Dir" << _kontestDir << endl;
-    kontestDir = _kontestDir;
+    //qDebug() << "World::World(1): Dir" << _klogDir << endl;
+    constrid = 2;
+    klogDir = _klogDir;
     kontestVersion = "";
     worldModel = new QSqlRelationalTableModel(this);
     numberOfEntities = 0;
@@ -63,16 +65,16 @@ World::World(const QString _kontestDir)
     created = false;
     //flagsDir=":/flags/";
     locator = new Locator();
-    dataProxy = new DataProxy_SQLite();
-    //identifyOS();
-    //awards = new Awards();
+    dataProxy = dp;
+    //qDebug() << "World::World(1): - END"  << endl;
 
 }
 
-World::World(const QString _kontestDir, const QString _kontestVer)
+World::World(DataProxy *dp, const QString _klogDir, const QString _kontestVer)
 {
-  //qDebug() << "World::World(2): Dir" << _kontestDir << endl;
-    kontestDir = _kontestDir;
+    //qDebug() << "World::World(2): Dir" << _klogDir << endl;
+    constrid = 3;
+    klogDir = _klogDir;
     kontestVersion = _kontestVer;    
     worldModel = new QSqlRelationalTableModel(this);
    //qDebug() << "World::World(2): 1" << endl;
@@ -84,10 +86,8 @@ World::World(const QString _kontestDir, const QString _kontestVer)
    //qDebug() << "World::World(2): 2" << endl;
     locator = new Locator();
    //qDebug() << "World::World(2): 3" << endl;
-    dataProxy = new DataProxy_SQLite();
-
-   //qDebug() << "World::World(2): 4" << endl;
-    //identifyOS();
+    dataProxy = dp;
+    //qDebug() << "World::World(2): - END" << endl;
 
 }
 
@@ -99,7 +99,7 @@ World::~World()
 
 bool World::recreate(const QString _worldFile)
 {
- //qDebug() << "World::recreate: " << _worldFile << endl;
+  //qDebug() << "World::recreate: " << _worldFile << endl;
 
     QSqlQuery query;
     if (query.exec("DELETE FROM entity"))
@@ -113,12 +113,14 @@ bool World::recreate(const QString _worldFile)
         else
         {//TODO: Manage the query error
           //qDebug() << "World::recreate: FAILED TO EMPTY prefixesofentity"  << endl;
+            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
             return false;
         }
     }
     else
     {//TODO: Manage the query error
       //qDebug() << "World::recreate: FAILED TO EMPTY entity"  << endl;
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
         return false;
     }
   //qDebug() << "World::recreate: END..."  << endl;
@@ -128,8 +130,8 @@ bool World::recreate(const QString _worldFile)
 bool World::create(const QString _worldFile)
 {
     //qDebug() << "World::create: " << _worldFile << endl;
-    //kontestDir = _worldFile;
-    //qDebug() << "World::create: 2 " <<  kontestDir << endl;
+    //klogDir = _worldFile;
+    //qDebug() << "World::create: 2 " <<  klogDir << endl;
 
 
     if (readCTYCSV(_worldFile))
@@ -145,7 +147,15 @@ bool World::create(const QString _worldFile)
     }
     if (created)
     {
-        dataProxy->updateISONames();
+        //dataProxy->updateISONames();
+        if (dataProxy->updateISONames())
+        {
+            //qDebug() << "World::create: updateISONames TRUE"  << endl;
+        }
+        else
+        {
+            //qDebug() << "World::create: updateISONames FALSE"  << endl;
+        }
     }
 
     //qDebug() << "World::create: END"  << endl;
@@ -404,25 +414,14 @@ int World::getPrefixId(const QString _qrz)
     //TODO: Instead of going from long to short, identify prefixes from the begining:
     // character(may be number) + number
 
-    //int errorCode;
-
     if (_qrz.length() < 1)
     {
         return -1;
     }
     int entityID = 0;
-    //int iaux1, iaux2;
-
-    //QString prefixl, prefixr;
-    //QString queryString;
-    //QSqlQuery query;
 
     QString aux = changeSlashAndFindPrefix((_qrz).toUpper());
 
-    //query.prepare("SELECT dxcc FROM prefixesofentity WHERE prefix==:prefix");
-
-    //QSqlDatabase::database().transaction();
-
     while ((entityID <= 0) && (aux.length()>=1) )
     {
         entityID = dataProxy->getDXCCFromPrefix(aux);
@@ -434,8 +433,6 @@ int World::getPrefixId(const QString _qrz)
          }
 
     }
-
-    //QSqlDatabase::database().commit();
      //qDebug() << "World::getPrefixId: " <<  _qrz << QString::number(entityID) << endl;
     return entityID;
 }
@@ -630,9 +627,6 @@ int World::getQRZARRLId(const QString _qrz)
         return -1;
     }
 
-    //QSqlQuery query;
-    //QString queryString;
-
     int prefixIdNumber = getPrefixId(_qrz);
     return prefixIdNumber;
 
@@ -1307,9 +1301,12 @@ bool World::readCTYCSV(const QString _worldFile)
                 //qDebug()  << "World::readCTYDAT(): Entity data added"  << endl;
             }
             else if (errorCode == 19)
-            {}
+            {
+                emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
+            }
             else
             {
+                emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
                 errorCode = query.lastError().number();
 
 
@@ -1367,6 +1364,7 @@ bool World::readCTYCSV(const QString _worldFile)
                     {}
                     else
                     {
+                        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
                         errorCode = query.lastError().number();
 
                        //qDebug() << "World::readCTYCSV(): Prefix data NOT added"  << endl;
