@@ -40,7 +40,6 @@
 
 #include "locator.h"
 #include "dataproxy.h"
-#include "dataproxy_sqlite.h"
 //#include "awards.h"
 
 
@@ -58,9 +57,9 @@ class World : public QWidget
     Q_OBJECT
 
 public:
-    World();
-    World(const QString _kontestDir);
-    World(const QString _kontestDir, const QString _kontestVer);
+    World(DataProxy *dp);
+    World(DataProxy *dp, const QString _klogDir);
+    World(DataProxy *dp, const QString _klogDir, const QString _kontestVer);
 
     ~World();
     bool create(const QString _worldFile);
@@ -125,7 +124,7 @@ private:
     int progressBarPosition;
 
     bool created;
-    QString kontestDir, kontestVersion;
+    QString klogDir, kontestVersion;
     int cqz, ituz, numberOfEntities;
     QString entityName;
     QString currentPrefix; // Used in the progressBar
@@ -144,11 +143,15 @@ private:
 
     Locator *locator;
     DataProxy *dataProxy;
+
+    int constrid; // Just an id for the constructor to check who is being executed at one specific time
     //Awards *awards;
     //FLAGS
     //QString flagsDir;
     //FLAGS-END
-
+signals:
+    //void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
 };
 
 
